from ... pyaz_utils import _call_az

def create(name, resource_group, workspace, caching_type=None, config_file=None, disk_count=None, disk_size=None, generate_ssh_keys=None, no_wait=None, password=None, ssh_key=None, storage_sku=None, subnet=None, user_name=None, vm_size=None):
    '''
    Create a file server.

    Required Parameters:
    - name -- Name of file server.
    - resource_group -- Name of resource group. You can configure a default value by setting up default workspace using `az batchai workspace set-default`.
    - workspace -- Name or ARM ID of the workspace. You can configure default workspace using `az batchai workspace set-default`

    Optional Parameters:
    - caching_type -- Caching type for premium disks. If not provided via command line or in configuration file, no caching will be used.
    - config_file -- A path to a json file containing file server create parameters (json representation of azure.mgmt.batchai.models.FileServerCreateParameters). Note, parameters given via command line will overwrite parameters specified in the configuration file.
    - disk_count -- Number of disks.
    - disk_size -- Disk size in Gb.
    - generate_ssh_keys -- Generate SSH public and private key files in ~/.ssh directory (if missing).
    - no_wait -- Do not wait for the long-running operation to finish.
    - password -- Optional password for the admin user created on the NFS node.
    - ssh_key -- Optional SSH public key value or path. If ommited and no password specified, default SSH key (~/.ssh/id_rsa.pub) will be used.
    - storage_sku -- The sku of storage account to persist VM.
    - subnet -- ARM ID of a virtual network subnet to put the file server in. If not provided via command line or in the configuration file, Batch AI will create a new virtual network and subnet under your subscription.
    - user_name -- Name of admin user account to be created on NFS node. If the value is not provided and no user configuration is provided in the config file, current user's name will be used.
    - vm_size -- VM size.
    '''
    return _call_az("az batchai file-server create", locals())


def list(resource_group, workspace):
    '''
    List file servers.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace -- Name of workspace.
    '''
    return _call_az("az batchai file-server list", locals())




from .... pyaz_utils import _call_az

def assign(gateway_name, identity, resource_group, no_wait=None):
    '''
    Assign a managed service identity to an application-gateway

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - identity -- Name or ID of the ManagedIdentity Resource
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az network application-gateway identity assign", locals())


def remove(gateway_name, resource_group, no_wait=None):
    '''
    Remove the managed service identity of an application-gateway

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az network application-gateway identity remove", locals())


def show(gateway_name, resource_group):
    '''
    Show the managed service identity of an application-gateway

    Required Parameters:
    - gateway_name -- Name of the application gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network application-gateway identity show", locals())




'''
Manage logic apps.
'''
from .. pyaz_utils import _call_az

def delete(name, resource_group, slot=None, yes=None):
    '''
    Delete a logic app.

    Required Parameters:
    - name -- name of the logic app.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az logicapp delete", locals())


def stop(name, resource_group, slot=None):
    '''
    Stop a logic app.

    Required Parameters:
    - name -- name of the logic app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az logicapp stop", locals())


def start(name, resource_group, slot=None):
    '''
    Start a logic app.

    Required Parameters:
    - name -- name of the logic app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az logicapp start", locals())


def restart(name, resource_group, slot=None):
    '''
    Restart a logic app.

    Required Parameters:
    - name -- name of the logic app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az logicapp restart", locals())


def create(name, resource_group, storage_account, app_insights=None, app_insights_key=None, consumption_plan_location=None, deployment_container_image_name=None, deployment_local_git=None, deployment_source_branch=None, deployment_source_url=None, disable_app_insights=None, docker_registry_server_password=None, docker_registry_server_user=None, os_type=None, plan=None, tags=None):
    '''
    Create a logic app.

    Required Parameters:
    - name -- name of the new logic app
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - storage_account -- Provide a string value of a Storage Account in the provided Resource Group. Or Resource ID of a Storage Account in a different Resource Group

    Optional Parameters:
    - app_insights -- Name of the existing App Insights project to be added to the logic app. Must be in the same resource group.
    - app_insights_key -- Instrumentation key of App Insights to be added.
    - consumption_plan_location -- Geographic location where logic app will be hosted. Use `az logicapp list-consumption-locations` to view available locations.
    - deployment_container_image_name -- Container image name from Docker Hub, e.g. publisher/image-name:tag
    - deployment_local_git -- enable local git
    - deployment_source_branch -- the branch to deploy
    - deployment_source_url -- Git repository URL to link with manual integration
    - disable_app_insights -- Disable creating application insights resource during logicapp create. No logs will be available.
    - docker_registry_server_password -- The container registry server password. Required for private registries.
    - docker_registry_server_user -- The container registry server username.
    - os_type -- Set the OS type for the app to be created.
    - plan -- name or resource id of the logicapp app service plan. Use 'appservice plan create' to get one. If using an App Service plan from a different resource group, the full resource id must be used and not the plan name.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az logicapp create", locals())


def list(resource_group=None):
    '''
    List logic apps.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az logicapp list", locals())


def show(name, resource_group, slot=None):
    '''
    Get the details of a logic app.

    Required Parameters:
    - name -- name of the logic app.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - slot -- the name of the slot. Default to the productions slot if not specified
    '''
    return _call_az("az logicapp show", locals())




'''
Manage MySQL databases on a server.
'''
from ... pyaz_utils import _call_az

def create(name, resource_group, server_name, charset=None, collation=None):
    '''
    Create a MySQL database.

    Required Parameters:
    - name -- The name of the database
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.

    Optional Parameters:
    - charset -- The charset of the database
    - collation -- The collation of the database
    '''
    return _call_az("az mysql db create", locals())


def delete(name, resource_group, server_name, yes=None):
    '''
    Delete a database.

    Required Parameters:
    - name -- The name of the database
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az mysql db delete", locals())


def show(name, resource_group, server_name):
    '''
    Show the details of a database.

    Required Parameters:
    - name -- The name of the database
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    '''
    return _call_az("az mysql db show", locals())


def list(resource_group, server_name):
    '''
    List the databases for a server.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Name of the Server.
    '''
    return _call_az("az mysql db list", locals())




from .... pyaz_utils import _call_az

def create(access, communities, filter_name, name, resource_group, location=None):
    '''
    Create a rule in a route filter.

    Required Parameters:
    - access -- The access type of the rule.
    - communities -- None
    - filter_name -- Name of the route filter.
    - name -- Name of the route filter rule.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    '''
    return _call_az("az network route-filter rule create", locals())


def list(filter_name, resource_group):
    '''
    List rules in a route filter.

    Required Parameters:
    - filter_name -- Name of the route filter.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network route-filter rule list", locals())


def show(filter_name, name, resource_group):
    '''
    Get the details of a rule in a route filter.

    Required Parameters:
    - filter_name -- Name of the route filter.
    - name -- Name of the route filter rule.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network route-filter rule show", locals())


def delete(filter_name, name, resource_group):
    '''
    Delete a rule from a route filter.

    Required Parameters:
    - filter_name -- Name of the route filter.
    - name -- Name of the route filter rule.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network route-filter rule delete", locals())


def update(filter_name, name, resource_group, add=None, force_string=None, remove=None, set=None):
    '''
    Update a rule in a route filter.

    Required Parameters:
    - filter_name -- Name of the route filter.
    - name -- Name of the route filter rule.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az network route-filter rule update", locals())


def list_service_communities():
    '''
    Gets all the available BGP service communities.
    '''
    return _call_az("az network route-filter rule list-service-communities", locals())




'''
Manage deleted web apps.
'''
from ... pyaz_utils import _call_az

def list(name=None, resource_group=None, slot=None):
    '''
    List web apps that have been deleted.

    Optional Parameters:
    - name -- name of the web app. If left unspecified, a name will be randomly generated. You can configure the default using `az configure --defaults web=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - slot -- Name of the deleted web app slot.
    '''
    return _call_az("az webapp deleted list", locals())


def restore(deleted_id, name, resource_group, restore_content_only=None, slot=None):
    '''
    Restore a deleted web app.

    Required Parameters:
    - deleted_id -- Resource ID of the deleted web app
    - name -- name of the web app to restore the deleted content to
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - restore_content_only -- restore only deleted files without web app settings
    - slot -- slot to restore the deleted content to
    '''
    return _call_az("az webapp deleted restore", locals())




'''
Manage Azure Cognitive Services accounts.
'''
from .. pyaz_utils import _call_az
from . import account, commitment_tier


def list(resource_group=None):
    '''
    Manage Azure Cognitive Services accounts.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cognitiveservices list", locals())




from .... pyaz_utils import _call_az

def list(account_name, resource_group):
    '''
    Get the private link resources that need to be created for a storage account.

    Required Parameters:
    - account_name -- The name of the storage account within the specified resource group. Storage account names must be between 3 and 24 characters in length and use numbers and lower-case letters only.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az storage account private-link-resource list", locals())




from ... pyaz_utils import _call_az
from . import event_subscription


def show(name, resource_group):
    '''
    Get the details of a system topic.

    Required Parameters:
    - name -- Name of the system topic.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventgrid system-topic show", locals())


def delete(name, resource_group, yes=None):
    '''
    Delete a system topic.

    Required Parameters:
    - name -- Name of the system topic.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az eventgrid system-topic delete", locals())


def list(odata_query=None, resource_group=None):
    '''
    List available system topics.

    Optional Parameters:
    - odata_query -- The OData query used for filtering the list results. Filtering is currently allowed on the Name property only. The supported operations include: CONTAINS, eq (for equal), ne (for not equal), AND, OR and NOT.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az eventgrid system-topic list", locals())


def create(name, resource_group, source, topic_type, identity=None, location=None, tags=None):
    '''
    Create a system topic.

    Required Parameters:
    - name -- Name of the system topic.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - source -- The ARM Id for the topic, e.g., /subscriptions/{SubId}/resourceGroups/{RgName}/providers/Microsoft.Storage/storageAccounts/{AccountName}
    - topic_type -- Name of the topic type.

    Optional Parameters:
    - identity -- The managed identity type for the resource.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az eventgrid system-topic create", locals())


def update(name, resource_group, identity=None, tags=None):
    '''
    Update a system topic.

    Required Parameters:
    - name -- Name of the system topic.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - identity -- The managed identity type for the resource.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    '''
    return _call_az("az eventgrid system-topic update", locals())




'''
Manage Linux or Windows virtual machines.
'''
from .. pyaz_utils import _call_az
from . import application, availability_set, boot_diagnostics, diagnostics, disk, encryption, extension, host, identity, image, nic, run_command, secret, unmanaged_disk, user


def capture(name, resource_group, vhd_name_prefix, overwrite=None, storage_container=None):
    '''
    Capture information for a stopped VM.

    Required Parameters:
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - vhd_name_prefix -- None

    Optional Parameters:
    - overwrite -- None
    - storage_container -- None
    '''
    return _call_az("az vm capture", locals())


def create(name, resource_group, accelerated_networking=None, admin_password=None, admin_username=None, asgs=None, assign_identity=None, attach_data_disks=None, attach_os_disk=None, authentication_type=None, availability_set=None, boot_diagnostics_storage=None, capacity_reservation_group=None, computer_name=None, count=None, custom_data=None, data_disk_caching=None, data_disk_delete_option=None, data_disk_encryption_sets=None, data_disk_sizes_gb=None, edge_zone=None, enable_agent=None, enable_auto_update=None, enable_hibernation=None, enable_hotpatching=None, enable_secure_boot=None, enable_vtpm=None, encryption_at_host=None, ephemeral_os_disk=None, ephemeral_os_disk_placement=None, eviction_policy=None, generate_ssh_keys=None, host=None, host_group=None, image=None, license_type=None, location=None, max_price=None, nic_delete_option=None, nics=None, no_wait=None, nsg=None, nsg_rule=None, os_disk_caching=None, os_disk_delete_option=None, os_disk_encryption_set=None, os_disk_name=None, os_disk_size_gb=None, os_type=None, patch_mode=None, plan_name=None, plan_product=None, plan_promotion_code=None, plan_publisher=None, platform_fault_domain=None, ppg=None, priority=None, private_ip_address=None, public_ip_address=None, public_ip_address_allocation=None, public_ip_address_dns_name=None, public_ip_sku=None, role=None, scope=None, secrets=None, security_type=None, size=None, specialized=None, ssh_dest_key_path=None, ssh_key_name=None, ssh_key_values=None, storage_account=None, storage_container_name=None, storage_sku=None, subnet=None, subnet_address_prefix=None, tags=None, ultra_ssd_enabled=None, use_unmanaged_disk=None, user_data=None, validate=None, vmss=None, vnet_address_prefix=None, vnet_name=None, workspace=None, zone=None):
    '''
    Create an Azure Virtual Machine.

    Required Parameters:
    - name -- Name of the virtual machine.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - accelerated_networking -- enable accelerated networking. Unless specified, CLI will enable it based on machine image and size
    - admin_password -- Password for the VM if authentication type is 'Password'.
    - admin_username -- Username for the VM. Default value is current username of OS. If the default value is system reserved, then default value will be set to azureuser. Please refer to https://docs.microsoft.com/rest/api/compute/virtualmachines/createorupdate#osprofile to get a full list of reserved values.
    - asgs -- Space-separated list of existing application security groups to associate with the VM.
    - assign_identity -- accept system or user assigned identities separated by spaces. Use '[system]' to refer system assigned identity, or a resource id to refer user assigned identity. Check out help for more examples
    - attach_data_disks -- Attach existing data disks to the VM. Can use the name or ID of a managed disk or the URI to an unmanaged disk VHD.
    - attach_os_disk -- Attach an existing OS disk to the VM. Can use the name or ID of a managed disk or the URI to an unmanaged disk VHD.
    - authentication_type -- Type of authentication to use with the VM. Defaults to password for Windows and SSH public key for Linux. "all" enables both ssh and password authentication. 
    - availability_set -- Name or ID of an existing availability set to add the VM to. None by default.
    - boot_diagnostics_storage -- pre-existing storage account name or its blob uri to capture boot diagnostics. Its sku should be one of Standard_GRS, Standard_LRS and Standard_RAGRS
    - capacity_reservation_group -- The ID or name of the capacity reservation group that is used to allocate. Pass in "None" to disassociate the capacity reservation group. Please note that if you want to delete a VM/VMSS that has been associated with capacity reservation group, you need to disassociate the capacity reservation group first.
    - computer_name -- None
    - count -- Number of virtual machines to create. Value range is [2, 250], inclusive. Don't specify this parameter if you want to create a normal single VM. The VMs are created in parallel. The output of this command is an array of VMs instead of one single VM. Each VM has its own public IP, NIC. VNET and NSG are shared. It is recommended that no existing public IP, NIC, VNET and NSG are in resource group. When --count is specified, --attach-data-disks, --attach-os-disk, --boot-diagnostics-storage, --computer-name, --host, --host-group, --nics, --os-disk-name, --private-ip-address, --public-ip-address, --public-ip-address-dns-name, --storage-account, --storage-container-name, --subnet, --use-unmanaged-disk, --vnet-name are not allowed.
    - custom_data -- Custom init script file or text (cloud-init, cloud-config, etc..)
    - data_disk_caching -- storage caching type for data disk(s), including 'None', 'ReadOnly', 'ReadWrite', etc. Use a singular value to apply on all disks, or use `<lun>=<vaule1> <lun>=<value2>` to configure individual disk
    - data_disk_delete_option -- Specify whether data disk should be deleted or detached upon VM deletion.
    - data_disk_encryption_sets -- Names or IDs (space delimited) of disk encryption sets for data disks.
    - data_disk_sizes_gb -- space-separated empty managed data disk sizes in GB to create
    - edge_zone -- The name of edge zone.
    - enable_agent -- Indicates whether virtual machine agent should be provisioned on the virtual machine. When this property is not specified, default behavior is to set it to true. This will ensure that VM Agent is installed on the VM so that extensions can be added to the VM later
    - enable_auto_update -- Indicate whether Automatic Updates is enabled for the Windows virtual machine
    - enable_hibernation -- The flag that enable or disable hibernation capability on the VM.
    - enable_hotpatching -- Patch VMs without requiring a reboot. --enable-agent must be set and --patch-mode must be set to AutomaticByPlatform
    - enable_secure_boot -- Enable secure boot. It is part of trusted launch.
    - enable_vtpm -- Enable vTPM. It is part of trusted launch.
    - encryption_at_host -- Enable Host Encryption for the VM or VMSS. This will enable the encryption for all the disks including Resource/Temp disk at host itself.
    - ephemeral_os_disk -- Allows you to create an OS disk directly on the host node, providing local disk performance and faster VM/VMSS reimage time.
    - ephemeral_os_disk_placement -- Only applicable when used with `--ephemeral-os-disk`. Allows you to choose the Ephemeral OS disk provisioning location.
    - eviction_policy -- The eviction policy for the Spot priority virtual machine. Default eviction policy is Deallocate for a Spot priority virtual machine
    - generate_ssh_keys -- Generate SSH public and private key files if missing. The keys will be stored in the ~/.ssh directory
    - host -- ID of the dedicated host that the VM will reside in. --host and --host-group can't be used together.
    - host_group -- Name or ID of the dedicated host group that the VM will reside in. --host and --host-group can't be used together.
    - image -- None
    - license_type -- Specifies that the Windows image or disk was licensed on-premises. To enable Azure Hybrid Benefit for Windows Server, use 'Windows_Server'. To enable Multitenant Hosting Rights for Windows 10, use 'Windows_Client'. For more information see the Azure Windows VM online docs.
    - location -- Location in which to create VM and related resources. If default location is not configured, will default to the resource group's location
    - max_price -- The maximum price (in US Dollars) you are willing to pay for a Spot VM/VMSS. -1 indicates that the Spot VM/VMSS should not be evicted for price reasons
    - nic_delete_option -- Specify what happens to the network interface when the VM is deleted. Use a singular value to apply on all resources, or use <Name>=<Value> to configure the delete behavior for individual resources. Possible options are Delete and Detach.
    - nics -- Names or IDs of existing NICs to attach to the VM. The first NIC will be designated as primary. If omitted, a new NIC will be created. If an existing NIC is specified, do not specify subnet, VNet, public IP or NSG.
    - no_wait -- Do not wait for the long-running operation to finish.
    - nsg -- The name to use when creating a new Network Security Group (default) or referencing an existing one. Can also reference an existing NSG by ID or specify "" for none ('""' in Azure CLI using PowerShell or --% operator).
    - nsg_rule -- NSG rule to create when creating a new NSG. Defaults to open ports for allowing RDP on Windows and allowing SSH on Linux. NONE represents no NSG rule
    - os_disk_caching -- Storage caching type for the VM OS disk. Default: ReadWrite
    - os_disk_delete_option -- Specify the behavior of the managed disk when the VM gets deleted i.e whether the managed disk is deleted or detached.
    - os_disk_encryption_set -- Name or ID of disk encryption set for OS disk.
    - os_disk_name -- The name of the new VM OS disk.
    - os_disk_size_gb -- OS disk size in GB to create.
    - os_type -- Type of OS installed on a custom VHD. Do not use when specifying an URN or URN alias.
    - patch_mode -- Mode of in-guest patching to IaaS virtual machine. Allowed values for Windows VM: AutomaticByOS, AutomaticByPlatform, Manual. Allowed values for Linux VM: AutomaticByPlatform, ImageDefault. Manual - You control the application of patches to a virtual machine. You do this by applying patches manually inside the VM. In this mode, automatic updates are disabled; the paramater --enable-auto-update must be false. AutomaticByOS - The virtual machine will automatically be updated by the OS. The parameter --enable-auto-update must be true. AutomaticByPlatform - the virtual machine will automatically updated by the OS. ImageDefault - The virtual machine's default patching configuration is used. The parameter --enable-agent and --enable-auto-update must be true
    - plan_name -- plan name
    - plan_product -- plan product
    - plan_promotion_code -- plan promotion code
    - plan_publisher -- plan publisher
    - platform_fault_domain -- Specify the scale set logical fault domain into which the virtual machine will be created. By default, the virtual machine will be automatically assigned to a fault domain that best maintains balance across available fault domains. This is applicable only if the virtualMachineScaleSet property of this virtual machine is set. The virtual machine scale set that is referenced, must have platform fault domain count. This property cannot be updated once the virtual machine is created. Fault domain assignment can be viewed in the virtual machine instance view
    - ppg -- The name or ID of the proximity placement group the VM should be associated with.
    - priority -- Priority. Use 'Spot' to run short-lived workloads in a cost-effective way. 'Low' enum will be deprecated in the future. Please use 'Spot' to deploy Azure spot VM and/or VMSS. Default to Regular.
    - private_ip_address -- Static private IP address (e.g. 10.0.0.5).
    - public_ip_address -- Name of the public IP address when creating one (default) or referencing an existing one. Can also reference an existing public IP by ID or specify "" for None ('""' in Azure CLI using PowerShell or --% operator).
    - public_ip_address_allocation -- None
    - public_ip_address_dns_name -- Globally unique DNS name for a newly created public IP.
    - public_ip_sku -- Public IP SKU. It is set to Basic by default. The public IP is supported to be created on edge zone only when it is 'Standard'
    - role -- Role name or id the system assigned identity will have
    - scope -- Scope that the system assigned identity can access
    - secrets -- One or many Key Vault secrets as JSON strings or files via `@{path}` containing `[{ "sourceVault": { "id": "value" }, "vaultCertificates": [{ "certificateUrl": "value", "certificateStore": "cert store name (only on windows)"}] }]`
    - security_type -- Specify if the VM is Trusted Launch enabled. See https://docs.microsoft.com/azure/virtual-machines/trusted-launch.
    - size -- The VM size to be created. See https://azure.microsoft.com/pricing/details/virtual-machines/ for size info.
    - specialized -- Indicate whether the source image is specialized.
    - ssh_dest_key_path -- Destination file path on the VM for the SSH key. If the file already exists, the specified key(s) are appended to the file. Destination path for SSH public keys is currently limited to its default value "/home/username/.ssh/authorized_keys" due to a known issue in Linux provisioning agent.
    - ssh_key_name -- Use it as public key in virtual machine. It should be an existing SSH key resource in Azure.
    - ssh_key_values -- None
    - storage_account -- Only applicable when used with `--use-unmanaged-disk`. The name to use when creating a new storage account or referencing an existing one. If omitted, an appropriate storage account in the same resource group and location will be used, or a new one will be created.
    - storage_container_name -- Only applicable when used with `--use-unmanaged-disk`. Name of the storage container for the VM OS disk. Default: vhds
    - storage_sku -- The SKU of the storage account with which to persist VM. Use a singular sku that would be applied across all disks, or specify individual disks. Usage: [--storage-sku SKU | --storage-sku ID=SKU ID=SKU ID=SKU...], where each ID is "os" or a 0-indexed lun. Allowed values: Standard_LRS, Premium_LRS, StandardSSD_LRS, UltraSSD_LRS, Premium_ZRS, StandardSSD_ZRS.
    - subnet -- The name of the subnet when creating a new VNet or referencing an existing one. Can also reference an existing subnet by ID. If both vnet-name and subnet are omitted, an appropriate VNet and subnet will be selected automatically, or a new one will be created.
    - subnet_address_prefix -- The subnet IP address prefix to use when creating a new VNet in CIDR format.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - ultra_ssd_enabled -- Enables or disables the capability to have 1 or more managed data disks with UltraSSD_LRS storage account
    - use_unmanaged_disk -- Do not use managed disk to persist VM
    - user_data -- UserData for the VM. It can be passed in as file or string.
    - validate -- Generate and validate the ARM template without creating any resources.
    - vmss -- Name or ID of an existing virtual machine scale set that the virtual machine should be assigned to. None by default.
    - vnet_address_prefix -- The IP address prefix to use when creating a new VNet in CIDR format.
    - vnet_name -- Name of the virtual network when creating a new one or referencing an existing one.
    - workspace -- Name or ID of Log Analytics Workspace. If you specify the workspace through its name, the workspace should be in the same resource group with the vm, otherwise a new workspace will be created.
    - zone -- Availability zone into which to provision the resource.
    '''
    return _call_az("az vm create", locals())


def convert(name, resource_group):
    '''
    Convert a VM with unmanaged disks to use managed disks.

    Required Parameters:
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az vm convert", locals())


def deallocate(name, resource_group, hibernate=None, no_wait=None):
    '''
    Deallocate a VM.

    Required Parameters:
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - hibernate -- Optional parameter to hibernate a virtual machine. (Feature in Preview).
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az vm deallocate", locals())


def delete(name, resource_group, force_deletion=None, no_wait=None, yes=None):
    '''
    Delete a VM.

    Required Parameters:
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - force_deletion -- Optional parameter to force delete virtual machines.(Feature in Preview).
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az vm delete", locals())


def generalize(name, resource_group, no_wait=None):
    '''
    Mark a VM as generalized, allowing it to be imaged for multiple deployments.

    Required Parameters:
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az vm generalize", locals())


def get_instance_view(name, resource_group):
    '''
    Get instance information about a VM.

    Required Parameters:
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az vm get-instance-view", locals())


def list(resource_group=None, show_details=None):
    '''
    List details of Virtual Machines.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - show_details -- show public ip address, FQDN, and power states. command will run slow
    '''
    return _call_az("az vm list", locals())


def list_ip_addresses(name=None, resource_group=None):
    '''
    List IP addresses associated with a VM.

    Optional Parameters:
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az vm list-ip-addresses", locals())


def list_sizes(location):
    '''
    List available sizes for VMs.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    '''
    return _call_az("az vm list-sizes", locals())


def list_skus(all=None, location=None, resource_type=None, size=None, zone=None):
    '''
    Get details for compute-related resource SKUs.

    Optional Parameters:
    - all -- show all information including vm sizes not available under the current subscription
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - resource_type -- resource types e.g. "availabilitySets", "snapshots", "disks", etc
    - size -- size name, partial name is accepted
    - zone -- show skus supporting availability zones
    '''
    return _call_az("az vm list-skus", locals())


def list_usage(location):
    '''
    List available usage resources for VMs.

    Required Parameters:
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    '''
    return _call_az("az vm list-usage", locals())


def list_vm_resize_options(name, resource_group):
    '''
    List available resizing options for VMs.

    Required Parameters:
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az vm list-vm-resize-options", locals())


def open_port(name, port, resource_group, apply_to_subnet=None, nsg_name=None, priority=None):
    '''
    Opens a VM to inbound traffic on specified ports.

    Required Parameters:
    - name -- The name of the virtual machine to open inbound traffic on.
    - port -- The port or port range (ex: 80-100) to open inbound traffic to. Use '*' to allow traffic to all ports. Use comma separated values to specify more than one port or port range.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - apply_to_subnet -- Allow inbound traffic on the subnet instead of the NIC
    - nsg_name -- The name of the network security group to create if one does not exist. Ignored if an NSG already exists.
    - priority -- Rule priority, between 100 (highest priority) and 4096 (lowest priority). Must be unique for each rule in the collection.
    '''
    return _call_az("az vm open-port", locals())


def perform_maintenance(name, resource_group):
    '''
    

    Required Parameters:
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az vm perform-maintenance", locals())


def redeploy(name, resource_group, no_wait=None):
    '''
    Redeploy an existing VM.

    Required Parameters:
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az vm redeploy", locals())


def resize(name, resource_group, size, no_wait=None):
    '''
    Update a VM's size.

    Required Parameters:
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - size -- None

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az vm resize", locals())


def restart(name, resource_group, force=None, no_wait=None):
    '''
    Restart VMs.

    Required Parameters:
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - force -- Force the VM to restart by redeploying it. Use if the VM is unresponsive.
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az vm restart", locals())


def show(name, resource_group, include_user_data=None, show_details=None):
    '''
    Get the details of a VM.

    Required Parameters:
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - include_user_data -- Include the user data properties in the query result.
    - show_details -- show public ip address, FQDN, and power states. command will run slow
    '''
    return _call_az("az vm show", locals())


def simulate_eviction(name, resource_group):
    '''
    Simulate the eviction of a Spot VM.

    Required Parameters:
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az vm simulate-eviction", locals())


def start(name, resource_group, no_wait=None):
    '''
    Start a stopped VM.

    Required Parameters:
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az vm start", locals())


def stop(name, resource_group, no_wait=None, skip_shutdown=None):
    '''
    Power off (stop) a running VM.

    Required Parameters:
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - skip_shutdown -- Skip shutdown and power-off immediately.
    '''
    return _call_az("az vm stop", locals())


def reapply(name, resource_group, no_wait=None):
    '''
    Reapply VMs.

    Required Parameters:
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az vm reapply", locals())


def update(name, resource_group, add=None, capacity_reservation_group=None, disk_caching=None, enable_hibernation=None, enable_secure_boot=None, enable_vtpm=None, ephemeral_os_disk_placement=None, force_string=None, host=None, host_group=None, license_type=None, max_price=None, no_wait=None, os_disk=None, ppg=None, priority=None, remove=None, set=None, size=None, ultra_ssd_enabled=None, user_data=None, workspace=None, write_accelerator=None):
    '''
    Update the properties of a VM.

    Required Parameters:
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - capacity_reservation_group -- The ID or name of the capacity reservation group that is used to allocate. Pass in "None" to disassociate the capacity reservation group. Please note that if you want to delete a VM/VMSS that has been associated with capacity reservation group, you need to disassociate the capacity reservation group first.
    - disk_caching -- Use singular value to apply across, or specify individual disks, e.g. 'os=ReadWrite 0=None 1=ReadOnly' should enable update os disk and 2 data disks
    - enable_hibernation -- The flag that enable or disable hibernation capability on the VM.
    - enable_secure_boot -- Enable secure boot.
    - enable_vtpm -- Enable vTPM.
    - ephemeral_os_disk_placement -- Only applicable when used with `--size`. Allows you to choose the Ephemeral OS disk provisioning location.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - host -- ID of the dedicated host that the VM will reside in. --host and --host-group can't be used together. You should deallocate the VM before update, and start the VM after update. Please check out help for more examples.
    - host_group -- Name or ID of the dedicated host group that the VM will reside in. --host and --host-group can't be used together. You should deallocate the VM before update, and start the VM after update. Please check out help for more examples.
    - license_type -- Specifies that the Windows image or disk was licensed on-premises. To enable Azure Hybrid Benefit for Windows Server, use 'Windows_Server'. To enable Multitenant Hosting Rights for Windows 10, use 'Windows_Client'. For more information see the Azure Windows VM online docs.
    - max_price -- The maximum price (in US Dollars) you are willing to pay for a Spot VM/VMSS. -1 indicates that the Spot VM/VMSS should not be evicted for price reasons
    - no_wait -- Do not wait for the long-running operation to finish.
    - os_disk -- Managed OS disk ID or name to swap to
    - ppg -- The name or ID of the proximity placement group the VM should be associated with.
    - priority -- Priority. Use 'Spot' to run short-lived workloads in a cost-effective way. 'Low' enum will be deprecated in the future. Please use 'Spot' to deploy Azure spot VM and/or VMSS. Default to Regular.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - size -- The new size of the virtual machine. See https://azure.microsoft.com/pricing/details/virtual-machines/ for size info.
    - ultra_ssd_enabled -- Enables or disables the capability to have 1 or more managed data disks with UltraSSD_LRS storage account
    - user_data -- UserData for the VM. It can be passed in as file or string. If empty string is passed in, the existing value will be deleted.
    - workspace -- Name or ID of Log Analytics Workspace. If you specify the workspace through its name, the workspace should be in the same resource group with the vm, otherwise a new workspace will be created.
    - write_accelerator -- enable/disable disk write accelerator. Use singular value 'true/false' to apply across, or specify individual disks, e.g.'os=true 1=true 2=true' for os disk and data disks with lun of 1 & 2
    '''
    return _call_az("az vm update", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the VM is met.

    Required Parameters:
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az vm wait", locals())


def auto_shutdown(name, resource_group, email=None, location=None, off=None, time=None, webhook=None):
    '''
    Manage auto-shutdown for VM.

    Required Parameters:
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - email -- The email recipient to send notifications to (can be a list of semi-colon separated email addresses)
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - off -- Turn off auto-shutdown for VM. Configuration will be cleared.
    - time -- The UTC time of day the schedule will occur every day. Format: hhmm. Example: 1730
    - webhook -- The webhook URL to which the notification will be sent
    '''
    return _call_az("az vm auto-shutdown", locals())


def assess_patches(name, resource_group):
    '''
    Assess patches on a VM.

    Required Parameters:
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az vm assess-patches", locals())


def install_patches(maximum_duration, name, reboot_setting, resource_group, classifications_to_include_linux=None, classifications_to_include_win=None, exclude_kbs_requiring_reboot=None, kb_numbers_to_exclude=None, kb_numbers_to_include=None, no_wait=None, package_name_masks_to_exclude=None, package_name_masks_to_include=None):
    '''
    Install patches on a VM.

    Required Parameters:
    - maximum_duration -- Specify the maximum amount of time that the operation will run. It must be an ISO 8601-compliant duration string such as PT4H (4 hours)
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - reboot_setting -- Define when it is acceptable to reboot a VM during a software update operation.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - classifications_to_include_linux -- Space-separated list of classifications to include for Linux VM.
    - classifications_to_include_win -- Space-separated list of classifications to include for Windows VM.
    - exclude_kbs_requiring_reboot -- Filter out KBs that don't have a reboot behavior of 'NeverReboots' when this is set. Applicable to Windows VM only
    - kb_numbers_to_exclude -- Space-separated list of KBs to exclude in the patch operation. Applicable to Windows VM only
    - kb_numbers_to_include -- Space-separated list of KBs to include in the patch operation. Applicable to Windows VM only
    - no_wait -- Do not wait for the long-running operation to finish.
    - package_name_masks_to_exclude -- Space-separated list of packages to exclude in the patch operation. Format: packageName_packageVersion. Applicable to Linux VM only
    - package_name_masks_to_include -- Space-separated list of packages to include in the patch operation. Format: packageName_packageVersion. Applicable to Linux VM only
    '''
    return _call_az("az vm install-patches", locals())




from .... pyaz_utils import _call_az

def list(resource_group, server_name):
    '''
    List the private link resources supported for a MySQL server.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Name of the Server.
    '''
    return _call_az("az mysql server private-link-resource list", locals())




'''
Manage resource providers.
'''
from .. pyaz_utils import _call_az
from . import operation, permission


def list(expand=None):
    '''
    

    Optional Parameters:
    - expand -- The properties to include in the results. For example, use &$expand=metadata in the query string to retrieve resource provider metadata. To include property aliases in response, use $expand=resourceTypes/aliases.
    '''
    return _call_az("az provider list", locals())


def show(namespace, expand=None):
    '''
    

    Required Parameters:
    - namespace -- the resource namespace, aka 'provider'

    Optional Parameters:
    - expand -- The $expand query parameter. For example, to include property aliases in response, use $expand=resourceTypes/aliases.
    '''
    return _call_az("az provider show", locals())


def register(namespace, accept_terms=None, consent_to_permissions=None, management_group_id=None, wait=None):
    '''
    Register a provider.

    Required Parameters:
    - namespace -- the resource namespace, aka 'provider'

    Optional Parameters:
    - accept_terms -- Accept market place terms and RP terms for RPaaS. Required when registering RPs from RPaaS, such as 'Microsoft.Confluent' and 'Microsoft.Datadog'.
    - consent_to_permissions -- A value indicating whether authorization is consented or not.
    - management_group_id -- The management group id to register.
    - wait -- wait for the registration to finish
    '''
    return _call_az("az provider register", locals())


def unregister(namespace, wait=None):
    '''
    Unregister a provider.

    Required Parameters:
    - namespace -- the resource namespace, aka 'provider'

    Optional Parameters:
    - wait -- wait for unregistration to finish
    '''
    return _call_az("az provider unregister", locals())




'''
Manage the registration definitions in Azure.
'''
from ... pyaz_utils import _call_az

def create(name, principal_id, role_definition_id, tenant_id, definition_id=None, description=None, plan_name=None, plan_product=None, plan_publisher=None, plan_version=None):
    '''
    Creates a new registration definition.

    Required Parameters:
    - name -- None
    - principal_id -- None
    - role_definition_id -- None
    - tenant_id -- None

    Optional Parameters:
    - definition_id -- None
    - description -- None
    - plan_name -- None
    - plan_product -- None
    - plan_publisher -- None
    - plan_version -- None
    '''
    return _call_az("az managedservices definition create", locals())


def list():
    '''
    List all the registration definitions under the default scope or under the subscription provided.
    '''
    return _call_az("az managedservices definition list", locals())


def delete(definition):
    '''
    Deletes a registration.

    Required Parameters:
    - definition -- The identifier (guid) or the fully qualified resource id of the registration definition. When resource id is used, subscription id and resource group parameters are ignored.
    '''
    return _call_az("az managedservices definition delete", locals())


def show(definition):
    '''
    Gets a registration definition.

    Required Parameters:
    - definition -- The identifier (guid) or the fully qualified resource id of the registration definition. When resource id is used, subscription id and resource group parameters are ignored.
    '''
    return _call_az("az managedservices definition show", locals())




from ..... pyaz_utils import _call_az

def create(data_connection_name, database_name, kusto_pool_name, resource_group, workspace_name, compression=None, consumer_group=None, data_format=None, event_hub_resource_id=None, event_system_properties=None, location=None, managed_identity_resource_id=None, mapping_rule_name=None, no_wait=None, table_name=None):
    '''
    Create a data connection.

    Required Parameters:
    - data_connection_name -- The name of the data connection.
    - database_name -- The name of the database in the Kusto pool.
    - kusto_pool_name -- The name of the Kusto pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace

    Optional Parameters:
    - compression -- The event hub messages compression type
    - consumer_group -- The event hub consumer group.
    - data_format -- The data format of the message. Optionally the data format can be added to each message.
    - event_hub_resource_id -- The resource ID of the event hub to be used to create a data connection.
    - event_system_properties -- System properties of the event hub
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - managed_identity_resource_id -- The resource ID of a managed identity (system or user assigned) to be used to authenticate with event hub.
    - mapping_rule_name -- The mapping rule to be used to ingest the data. Optionally the mapping information can be added to each message.
    - no_wait -- Do not wait for the long-running operation to finish.
    - table_name -- The table where the data should be ingested. Optionally the table information can be added to each message.
    '''
    return _call_az("az synapse kusto data-connection event-hub create", locals())


def update(data_connection_name, database_name, kusto_pool_name, resource_group, workspace_name, compression=None, consumer_group=None, data_format=None, event_hub_resource_id=None, event_system_properties=None, location=None, managed_identity_resource_id=None, mapping_rule_name=None, no_wait=None, table_name=None):
    '''
    Updates a data connection.

    Required Parameters:
    - data_connection_name -- The name of the data connection.
    - database_name -- The name of the database in the Kusto pool.
    - kusto_pool_name -- The name of the Kusto pool.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace_name -- The name of the workspace

    Optional Parameters:
    - compression -- The event hub messages compression type
    - consumer_group -- The event hub consumer group.
    - data_format -- The data format of the message. Optionally the data format can be added to each message.
    - event_hub_resource_id -- The resource ID of the event hub to be used to create a data connection.
    - event_system_properties -- System properties of the event hub
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - managed_identity_resource_id -- The resource ID of a managed identity (system or user assigned) to be used to authenticate with event hub.
    - mapping_rule_name -- The mapping rule to be used to ingest the data. Optionally the mapping information can be added to each message.
    - no_wait -- Do not wait for the long-running operation to finish.
    - table_name -- The table where the data should be ingested. Optionally the table information can be added to each message.
    '''
    return _call_az("az synapse kusto data-connection event-hub update", locals())




'''
Manage a collection of steps for building, testing and OS & Framework patching container images using Azure Container Registries.
'''
from ... pyaz_utils import _call_az
from . import credential, identity, timer


def create(name, registry, agent_pool=None, arg=None, assign_identity=None, auth_mode=None, base_image_trigger_enabled=None, base_image_trigger_name=None, base_image_trigger_type=None, commit_trigger_enabled=None, context=None, cpu=None, file=None, git_access_token=None, image=None, is_system_task=None, log_template=None, no_cache=None, no_push=None, platform=None, pull_request_trigger_enabled=None, resource_group=None, schedule=None, secret_arg=None, set=None, set_secret=None, source_trigger_name=None, status=None, target=None, timeout=None, update_trigger_endpoint=None, update_trigger_payload_type=None, values=None):
    '''
    Create a series of steps for building, testing and OS & Framework patching containers. Tasks support triggers from git commits and base image updates.

    Required Parameters:
    - name -- The name of the task.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - agent_pool -- The name of the agent pool.
    - arg -- Build argument in '--arg name[=value]' format. Multiples supported by passing '--arg` multiple times.
    - assign_identity -- Assigns managed identities to the task. Use '[system]' to refer to the system-assigned identity or a resource ID to refer to a user-assigned identity. Please see https://aka.ms/acr/tasks/task-create-managed-identity for more information.
    - auth_mode -- Auth mode of the source registry.
    - base_image_trigger_enabled -- Indicates whether the base image trigger is enabled.
    - base_image_trigger_name -- The name of the base image trigger.
    - base_image_trigger_type -- The type of the auto trigger for base image dependency updates.
    - commit_trigger_enabled -- Indicates whether the source control commit trigger is enabled.
    - context -- The full URL to the source code repository (Requires '.git' suffix for a github repo) or the repository of an OCI artifact in an Azure container registry (e.g., 'oci://myregistry.azurecr.io/myartifact:mytag'). If '/dev/null' is specified, the value will be set to None and ignored. This is a required argument if the task is not a system task.
    - cpu -- The CPU configuration in terms of number of cores required for the run.
    - file -- Relative path of the the task/docker file to the source code root folder. Task files must be suffixed with '.yaml' or piped from the standard input using '-'.
    - git_access_token -- The access token used to access the source control provider.
    - image -- The name and tag of the image using the format: '-t repo/image:tag'. Multiple tags are supported by passing -t multiple times.
    - is_system_task -- Indicates whether the task resource is a system task. The name of the task must be 'quicktask'. Only applicable to CMK enabled registry.
    - log_template -- The repository and tag template for run log artifact using the format: 'log/repo:tag' (e.g., 'acr/logs:{{.Run.ID}}'). Only applicable to CMK enabled registry.
    - no_cache -- Indicates whether the image cache is enabled.
    - no_push -- Indicates whether the image built should be pushed to the registry.
    - platform -- The platform where build/task is run, Eg, 'windows' and 'linux'. When it's used in build commands, it also can be specified in 'os/arch/variant' format for the resulting image. Eg, linux/arm/v7. The 'arch' and 'variant' parts are optional.
    - pull_request_trigger_enabled -- Indicates whether the source control pull request trigger is enabled. The trigger is disabled by default.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - schedule -- Schedule for a timer trigger represented as a cron expression. An optional trigger name can be specified using `--schedule name:schedule` format. Multiples supported by passing --schedule multiple times.
    - secret_arg -- Secret build argument in '--secret-arg name[=value]' format. Multiples supported by passing --secret-arg multiple times.
    - set -- Task value in '--set name[=value]' format. Multiples supported by passing --set multiple times.
    - set_secret -- Secret task value in '--set-secret name[=value]' format. Multiples supported by passing --set-secret multiple times.
    - source_trigger_name -- The name of the source trigger.
    - status -- The current status of task.
    - target -- The name of the target build stage.
    - timeout -- The timeout in seconds.
    - update_trigger_endpoint -- The full URL of the endpoint to receive base image update trigger notifications.
    - update_trigger_payload_type -- Indicates whether to include metadata about the base image trigger in the payload alongwith the update trigger token, when a notification is sent.
    - values -- The task values/parameters file path relative to the source context.
    '''
    return _call_az("az acr task create", locals())


def show(name, registry, resource_group=None, with_secure_properties=None):
    '''
    Get the properties of a named task for an Azure Container Registry.

    Required Parameters:
    - name -- The name of the task.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - with_secure_properties -- Indicates whether the secure properties of a task should be returned.
    '''
    return _call_az("az acr task show", locals())


def list(registry, resource_group=None):
    '''
    List the tasks for an Azure Container Registry.

    Required Parameters:
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr task list", locals())


def delete(name, registry, resource_group=None, yes=None):
    '''
    Delete a task from an Azure Container Registry.

    Required Parameters:
    - name -- The name of the task.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az acr task delete", locals())


def update(name, registry, agent_pool=None, arg=None, auth_mode=None, base_image_trigger_enabled=None, base_image_trigger_type=None, commit_trigger_enabled=None, context=None, cpu=None, file=None, git_access_token=None, image=None, log_template=None, no_cache=None, no_push=None, platform=None, pull_request_trigger_enabled=None, resource_group=None, secret_arg=None, set=None, set_secret=None, status=None, target=None, timeout=None, update_trigger_endpoint=None, update_trigger_payload_type=None, values=None):
    '''
    Update a task for an Azure Container Registry.

    Required Parameters:
    - name -- The name of the task.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - agent_pool -- The name of the agent pool.
    - arg -- Build argument in '--arg name[=value]' format. Multiples supported by passing '--arg` multiple times.
    - auth_mode -- Auth mode of the source registry.
    - base_image_trigger_enabled -- Indicates whether the base image trigger is enabled.
    - base_image_trigger_type -- The type of the auto trigger for base image dependency updates.
    - commit_trigger_enabled -- Indicates whether the source control commit trigger is enabled.
    - context -- The full URL to the source code repository (Requires '.git' suffix for a github repo) or the repository of an OCI artifact in an Azure container registry (e.g., 'oci://myregistry.azurecr.io/myartifact:mytag'). If '/dev/null' is specified, the value will be set to None and ignored. This is a required argument if the task is not a system task.
    - cpu -- The CPU configuration in terms of number of cores required for the run.
    - file -- Relative path of the the task/docker file to the source code root folder. Task files must be suffixed with '.yaml' or piped from the standard input using '-'.
    - git_access_token -- The access token used to access the source control provider.
    - image -- The name and tag of the image using the format: '-t repo/image:tag'. Multiple tags are supported by passing -t multiple times.
    - log_template -- The repository and tag template for run log artifact using the format: 'log/repo:tag' (e.g., 'acr/logs:{{.Run.ID}}'). Only applicable to CMK enabled registry.
    - no_cache -- Indicates whether the image cache is enabled.
    - no_push -- Indicates whether the image built should be pushed to the registry.
    - platform -- The platform where build/task is run, Eg, 'windows' and 'linux'. When it's used in build commands, it also can be specified in 'os/arch/variant' format for the resulting image. Eg, linux/arm/v7. The 'arch' and 'variant' parts are optional.
    - pull_request_trigger_enabled -- Indicates whether the source control pull request trigger is enabled. The trigger is disabled by default.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - secret_arg -- Secret build argument in '--secret-arg name[=value]' format. Multiples supported by passing --secret-arg multiple times.
    - set -- Task value in '--set name[=value]' format. Multiples supported by passing --set multiple times.
    - set_secret -- Secret task value in '--set-secret name[=value]' format. Multiples supported by passing --set-secret multiple times.
    - status -- The current status of task.
    - target -- The name of the target build stage.
    - timeout -- The timeout in seconds.
    - update_trigger_endpoint -- The full URL of the endpoint to receive base image update trigger notifications.
    - update_trigger_payload_type -- Indicates whether to include metadata about the base image trigger in the payload alongwith the update trigger token, when a notification is sent.
    - values -- The task values/parameters file path relative to the source context.
    '''
    return _call_az("az acr task update", locals())


def run(name, registry, agent_pool=None, arg=None, context=None, file=None, log_template=None, no_logs=None, no_wait=None, resource_group=None, secret_arg=None, set=None, set_secret=None, target=None, update_trigger_token=None):
    '''
    Manually trigger a task that might otherwise be waiting for git commits or base image update triggers.

    Required Parameters:
    - name -- The name of the task.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - agent_pool -- The name of the agent pool.
    - arg -- Build argument in '--arg name[=value]' format. Multiples supported by passing '--arg` multiple times.
    - context -- The full URL to the source code repository (Requires '.git' suffix for a github repo) or the repository of an OCI artifact in an Azure container registry (e.g., 'oci://myregistry.azurecr.io/myartifact:mytag'). If '/dev/null' is specified, the value will be set to None and ignored. This is a required argument if the task is not a system task.
    - file -- Relative path of the the task/docker file to the source code root folder. Task files must be suffixed with '.yaml' or piped from the standard input using '-'.
    - log_template -- The repository and tag template for run log artifact using the format: 'log/repo:tag' (e.g., 'acr/logs:{{.Run.ID}}'). Only applicable to CMK enabled registry.
    - no_logs -- Do not show logs after successfully queuing the build.
    - no_wait -- Do not wait for the run to complete and return immediately after queuing the run.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - secret_arg -- Secret build argument in '--secret-arg name[=value]' format. Multiples supported by passing --secret-arg multiple times.
    - set -- Task value in '--set name[=value]' format. Multiples supported by passing --set multiple times.
    - set_secret -- Secret task value in '--set-secret name[=value]' format. Multiples supported by passing --set-secret multiple times.
    - target -- The name of the target build stage.
    - update_trigger_token -- The payload that will be passed back alongwith the base image trigger notification.
    '''
    return _call_az("az acr task run", locals())


def list_runs(registry, image=None, name=None, resource_group=None, run_status=None, top=None):
    '''
    List all of the executed runs for an Azure Container Registry, with the ability to filter by a specific Task.

    Required Parameters:
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - image -- The name of the image. May include a tag in the format 'name:tag' or digest in the format 'name@digest'.
    - name -- The name of the task.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - run_status -- The current status of run.
    - top -- Limit the number of latest runs in the results.
    '''
    return _call_az("az acr task list-runs", locals())


def show_run(registry, run_id, resource_group=None):
    '''
    Get the properties of a specified run of an Azure Container Registry Task.

    Required Parameters:
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`
    - run_id -- The unique run identifier.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr task show-run", locals())


def cancel_run(registry, run_id, resource_group=None):
    '''
    Cancel a specified run of an Azure Container Registry.

    Required Parameters:
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`
    - run_id -- The unique run identifier.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr task cancel-run", locals())


def update_run(registry, run_id, no_archive=None, resource_group=None):
    '''
    Patch the run properties of an Azure Container Registry Task.

    Required Parameters:
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`
    - run_id -- The unique run identifier.

    Optional Parameters:
    - no_archive -- Indicates whether the run should be archived.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr task update-run", locals())


def logs(registry, image=None, name=None, resource_group=None, run_id=None):
    '''
    Show logs for a particular run. If no run-id is supplied, show logs for the last created run.

    Required Parameters:
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - image -- The name of the image. May include a tag in the format 'name:tag' or digest in the format 'name@digest'.
    - name -- The name of the task.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - run_id -- The unique run identifier.
    '''
    return _call_az("az acr task logs", locals())




'''
Manage Synapse's datasets.
'''
from ... pyaz_utils import _call_az

def create(file, name, workspace_name, no_wait=None):
    '''
    Create a dataset.

    Required Parameters:
    - file -- Properties may be supplied from a JSON file using the `@{path}` syntax or a JSON string.
    - name -- The dataset name.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az synapse dataset create", locals())


def set(file, name, workspace_name, no_wait=None):
    '''
    Update an exist dataset.

    Required Parameters:
    - file -- Properties may be supplied from a JSON file using the `@{path}` syntax or a JSON string.
    - name -- The dataset name.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az synapse dataset set", locals())


def update(file, name, workspace_name, no_wait=None):
    '''
    Update an exist dataset.

    Required Parameters:
    - file -- Properties may be supplied from a JSON file using the `@{path}` syntax or a JSON string.
    - name -- The dataset name.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az synapse dataset update", locals())


def list(workspace_name):
    '''
    List datasets.

    Required Parameters:
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse dataset list", locals())


def show(name, workspace_name):
    '''
    Get a dataset.

    Required Parameters:
    - name -- The dataset name.
    - workspace_name -- The workspace name.
    '''
    return _call_az("az synapse dataset show", locals())


def delete(name, workspace_name, no_wait=None, yes=None):
    '''
    Delete a dataset.

    Required Parameters:
    - name -- The dataset name.
    - workspace_name -- The workspace name.

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az synapse dataset delete", locals())




from .... pyaz_utils import _call_az

def info(name, parent_protocol, registry, resource_group=None):
    '''
    Retrieve information required to activate a connected registry.

    Required Parameters:
    - name -- Name for the connected registry. Name must be between 5 to 40 character long, start with a letter and contain only alphanumeric characters (including ‘_’ or ‘-’). Name must be unique under the Cloud ACR hierarchy.
    - parent_protocol -- Specify the protocol used to communicate with its parent.
    - registry -- The login server of the Cloud ACR registry. Must be the FQDN to support also Azure Stack.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr connected-registry install info", locals())


def renew_credentials(name, parent_protocol, registry, resource_group=None, yes=None):
    '''
    Retrieve information required to activate a connected registry, and renews the sync token credentials.

    Required Parameters:
    - name -- Name for the connected registry. Name must be between 5 to 40 character long, start with a letter and contain only alphanumeric characters (including ‘_’ or ‘-’). Name must be unique under the Cloud ACR hierarchy.
    - parent_protocol -- Specify the protocol used to communicate with its parent.
    - registry -- The login server of the Cloud ACR registry. Must be the FQDN to support also Azure Stack.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az acr connected-registry install renew-credentials", locals())




'''
Manage a Data Lake Store filesystem.
'''
from ... pyaz_utils import _call_az
from . import access


def show(account, path):
    '''
    Get file or folder information in a Data Lake Store account.

    Required Parameters:
    - account -- Name of the Data Lake Store account.
    - path -- The path in the specified Data Lake Store account where the action should take place. In the format '/folder/file.txt', where the first '/' after the DNS indicates the root of the file system.
    '''
    return _call_az("az dls fs show", locals())


def list(account, path):
    '''
    List the files and folders in a Data Lake Store account.

    Required Parameters:
    - account -- Name of the Data Lake Store account.
    - path -- The path in the specified Data Lake Store account where the action should take place. In the format '/folder/file.txt', where the first '/' after the DNS indicates the root of the file system.
    '''
    return _call_az("az dls fs list", locals())


def create(account, path, content=None, folder=None, force=None):
    '''
    Creates a file or folder in a Data Lake Store account.

    Required Parameters:
    - account -- Name of the Data Lake Store account.
    - path -- The path in the specified Data Lake Store account where the action should take place. In the format '/folder/file.txt', where the first '/' after the DNS indicates the root of the file system.

    Optional Parameters:
    - content -- None
    - folder -- Indicates that this new item is a folder and not a file.
    - force -- Indicates that, if the file or folder exists, it should be overwritten
    '''
    return _call_az("az dls fs create", locals())


def append(account, content, path):
    '''
    Append content to a file in a Data Lake Store account.

    Required Parameters:
    - account -- Name of the Data Lake Store account.
    - content -- None
    - path -- The path in the specified Data Lake Store account where the action should take place. In the format '/folder/file.txt', where the first '/' after the DNS indicates the root of the file system.
    '''
    return _call_az("az dls fs append", locals())


def delete(account, path, recurse=None):
    '''
    Delete a file or folder in a Data Lake Store account.

    Required Parameters:
    - account -- Name of the Data Lake Store account.
    - path -- The path in the specified Data Lake Store account where the action should take place. In the format '/folder/file.txt', where the first '/' after the DNS indicates the root of the file system.

    Optional Parameters:
    - recurse -- Indicates this should be a recursive delete of the folder.
    '''
    return _call_az("az dls fs delete", locals())


def upload(account, destination_path, source_path, block_size=None, buffer_size=None, chunk_size=None, overwrite=None, thread_count=None):
    '''
    Upload a file or folder to a Data Lake Store account.

    Required Parameters:
    - account -- Name of the Data Lake Store account.
    - destination_path -- None
    - source_path -- None

    Optional Parameters:
    - block_size -- Number of bytes for a block. Within each chunk, we write a smaller block for each API call. This block cannot be bigger than a chunk.
    - buffer_size -- Number of bytes for internal buffer. This block cannot be bigger than a chunk and cannot be smaller than a block.
    - chunk_size -- Number of bytes for a chunk. Large files are split into chunks. Files smaller than this number will always be transferred in a single thread.
    - overwrite -- Indicates that, if the destination file or folder exists, it should be overwritten
    - thread_count -- Specify the parallelism of the upload. Default is the number of cores in the local machine.
    '''
    return _call_az("az dls fs upload", locals())


def download(account, destination_path, source_path, block_size=None, buffer_size=None, chunk_size=None, overwrite=None, thread_count=None):
    '''
    Download a file or folder from a Data Lake Store account to the local machine.

    Required Parameters:
    - account -- Name of the Data Lake Store account.
    - destination_path -- None
    - source_path -- None

    Optional Parameters:
    - block_size -- Number of bytes for a block. Within each chunk, we write a smaller block for each API call. This block cannot be bigger than a chunk.
    - buffer_size -- Number of bytes for internal buffer. This block cannot be bigger than a chunk and cannot be smaller than a block.
    - chunk_size -- Number of bytes for a chunk. Large files are split into chunks. Files smaller than this number will always be transferred in a single thread.
    - overwrite -- Indicates that, if the destination file or folder exists, it should be overwritten
    - thread_count -- Specify the parallelism of the download. Default is the number of cores in the local machine.
    '''
    return _call_az("az dls fs download", locals())


def test(account, path):
    '''
    Test for the existence of a file or folder in a Data Lake Store account.

    Required Parameters:
    - account -- Name of the Data Lake Store account.
    - path -- The path in the specified Data Lake Store account where the action should take place. In the format '/folder/file.txt', where the first '/' after the DNS indicates the root of the file system.
    '''
    return _call_az("az dls fs test", locals())


def preview(account, path, force=None, length=None, offset=None):
    '''
    Preview the content of a file in a Data Lake Store account.

    Required Parameters:
    - account -- Name of the Data Lake Store account.
    - path -- The path in the specified Data Lake Store account where the action should take place. In the format '/folder/file.txt', where the first '/' after the DNS indicates the root of the file system.

    Optional Parameters:
    - force -- Indicates that, if the preview is larger than 1MB, still retrieve it. This can potentially be very slow, depending on how large the file is.
    - length -- None
    - offset -- None
    '''
    return _call_az("az dls fs preview", locals())


def join(account, destination_path, source_paths, force=None):
    '''
    Join files in a Data Lake Store account into one file.

    Required Parameters:
    - account -- Name of the Data Lake Store account.
    - destination_path -- None
    - source_paths -- The list of files in the specified Data Lake Store account to join.

    Optional Parameters:
    - force -- Indicates that, if the destination file already exists, it should be overwritten
    '''
    return _call_az("az dls fs join", locals())


def move(account, destination_path, source_path, force=None):
    '''
    Move a file or folder in a Data Lake Store account.

    Required Parameters:
    - account -- Name of the Data Lake Store account.
    - destination_path -- None
    - source_path -- None

    Optional Parameters:
    - force -- Indicates that, if the destination file or folder already exists, it should be overwritten and replaced with the file or folder being moved.
    '''
    return _call_az("az dls fs move", locals())


def set_expiry(account, expiration_time, path):
    '''
    Set the expiration time for a file.

    Required Parameters:
    - account -- Name of the Data Lake Store account.
    - expiration_time -- The absolute value of the expiration time expressed as milliseconds since the epoch.
    - path -- The path in the specified Data Lake Store account where the action should take place. In the format '/folder/file.txt', where the first '/' after the DNS indicates the root of the file system.
    '''
    return _call_az("az dls fs set-expiry", locals())


def remove_expiry(account, path):
    '''
    Remove the expiration time for a file.

    Required Parameters:
    - account -- Name of the Data Lake Store account.
    - path -- The path in the specified Data Lake Store account where the action should take place. In the format '/folder/file.txt', where the first '/' after the DNS indicates the root of the file system.
    '''
    return _call_az("az dls fs remove-expiry", locals())




'''
Manage SQL resources of Azure Cosmos DB account.
'''
from ... pyaz_utils import _call_az
from . import container, database, restorable_container, restorable_database, restorable_resource, stored_procedure, trigger, user_defined_function


def retrieve_latest_backup_time(account_name, container_name, database_name, location, resource_group):
    '''
    Retrieves latest restorable timestamp for the given sql container in given region.

    Required Parameters:
    - account_name -- Name of the CosmosDB database account
    - container_name -- Name of the CosmosDB Sql container name
    - database_name -- Name of the CosmosDB Sql database name
    - location -- Location of the account
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cosmosdb sql retrieve-latest-backup-time", locals())




from .... pyaz_utils import _call_az

def add(name, resource_group, ip_address=None, subnet=None, vnet_name=None):
    '''
    Add a network rule.

    Required Parameters:
    - name -- cognitive service account name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - ip_address -- IPv4 address or CIDR range.
    - subnet -- Name or ID of subnet. If name is supplied, `--vnet-name` must be supplied.
    - vnet_name -- Name of a virtual network.
    '''
    return _call_az("az cognitiveservices account network-rule add", locals())


def list(name, resource_group):
    '''
    List network rules.

    Required Parameters:
    - name -- cognitive service account name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az cognitiveservices account network-rule list", locals())


def remove(name, resource_group, ip_address=None, subnet=None, vnet_name=None):
    '''
    Remove a network rule.

    Required Parameters:
    - name -- cognitive service account name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - ip_address -- IPv4 address or CIDR range.
    - subnet -- Name or ID of subnet. If name is supplied, `--vnet-name` must be supplied.
    - vnet_name -- Name of a virtual network.
    '''
    return _call_az("az cognitiveservices account network-rule remove", locals())




from .... pyaz_utils import _call_az

def create(end_ip_address, name, resource_group, server_name, start_ip_address):
    '''
    Create a new firewall rule for a server.

    Required Parameters:
    - end_ip_address -- The end IP address of the firewall rule. Must be IPv4 format. Use value '0.0.0.0' to represent all Azure-internal IP addresses.
    - name -- The name of the firewall rule. The firewall rule name cannot be empty. The firewall rule name can only contain 0-9, a-z, A-Z, '-' and '_'. Additionally, the firewall rule name cannot exceed 128 characters.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    - start_ip_address -- The start IP address of the firewall rule. Must be IPv4 format. Use value '0.0.0.0' to represent all Azure-internal IP addresses.
    '''
    return _call_az("az postgres server firewall-rule create", locals())


def delete(name, resource_group, server_name, yes=None):
    '''
    Delete a firewall rule.

    Required Parameters:
    - name -- The name of the firewall rule. The firewall rule name cannot be empty. The firewall rule name can only contain 0-9, a-z, A-Z, '-' and '_'. Additionally, the firewall rule name cannot exceed 128 characters.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.

    Optional Parameters:
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az postgres server firewall-rule delete", locals())


def show(name, resource_group, server_name):
    '''
    Get the details of a firewall rule.

    Required Parameters:
    - name -- The name of the firewall rule. The firewall rule name cannot be empty. The firewall rule name can only contain 0-9, a-z, A-Z, '-' and '_'. Additionally, the firewall rule name cannot exceed 128 characters.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    '''
    return _call_az("az postgres server firewall-rule show", locals())


def list(resource_group, server_name):
    '''
    List all firewall rules for a server.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.
    '''
    return _call_az("az postgres server firewall-rule list", locals())


def update(name, resource_group, server_name, add=None, end_ip_address=None, force_string=None, remove=None, set=None, start_ip_address=None):
    '''
    Update a firewall rule.

    Required Parameters:
    - name -- The name of the firewall rule. The firewall rule name cannot be empty. The firewall rule name can only contain 0-9, a-z, A-Z, '-' and '_'. Additionally, the firewall rule name cannot exceed 128 characters.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server_name -- Name of the server. The name can contain only lowercase letters, numbers, and the hyphen (-) character. Minimum 3 characters and maximum 63 characters.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - end_ip_address -- The end IP address of the firewall rule. Must be IPv4 format. Use value '0.0.0.0' to represent all Azure-internal IP addresses.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - start_ip_address -- The start IP address of the firewall rule. Must be IPv4 format. Use value '0.0.0.0' to represent all Azure-internal IP addresses.
    '''
    return _call_az("az postgres server firewall-rule update", locals())




'''
View all possible traffic between resources for the subscription and location, based on connection type.
'''
from ... pyaz_utils import _call_az

def list():
    '''
    list of all possible traffic between resources for the subscription.
    '''
    return _call_az("az security allowed_connections list", locals())


def show(name, resource_group):
    '''
    List all possible traffic between resources for the subscription and location, based on connection type.

    Required Parameters:
    - name -- name of the resource to be fetched
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az security allowed_connections show", locals())




from ... pyaz_utils import _call_az

def disable(name, resource_group):
    '''
    Disable the boot diagnostics on a VM.

    Required Parameters:
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az vm boot-diagnostics disable", locals())


def enable(name, resource_group, storage=None):
    '''
    Enable the boot diagnostics on a VM.

    Required Parameters:
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - storage -- None
    '''
    return _call_az("az vm boot-diagnostics enable", locals())


def get_boot_log(name, resource_group):
    '''
    Get the boot diagnostics log from a VM.

    Required Parameters:
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az vm boot-diagnostics get-boot-log", locals())


def get_boot_log_uris(name, resource_group, expire=None):
    '''
    Get SAS URIs for a virtual machine's boot diagnostic logs.

    Required Parameters:
    - name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - expire -- None
    '''
    return _call_az("az vm boot-diagnostics get-boot-log-uris", locals())




from .... pyaz_utils import _call_az

def add(external_mappings, gateway_name, internal_mappings, name, resource_group, ip_config_id=None, mode=None, no_wait=None, type=None):
    '''
    Add nat rule in a virtual network gateway

    Required Parameters:
    - external_mappings -- The private IP address external mapping for NAT.
    - gateway_name -- Virtual network gateway name
    - internal_mappings -- The private IP address internal mapping for NAT.
    - name -- The name of the resource that is unique within a resource group. This name can be used to access the resource.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - ip_config_id -- The IP Configuration ID this NAT rule applies to.
    - mode -- The Source NAT direction of a VPN NAT.
    - no_wait -- Do not wait for the long-running operation to finish.
    - type -- The type of NAT rule for VPN NAT.
    '''
    return _call_az("az network vnet-gateway nat-rule add", locals())


def list(gateway_name, resource_group):
    '''
    List nat rule for a virtual network gateway

    Required Parameters:
    - gateway_name -- Virtual network gateway name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network vnet-gateway nat-rule list", locals())


def remove(gateway_name, name, resource_group, no_wait=None):
    '''
    Remove nat rule from a virtual network gateway

    Required Parameters:
    - gateway_name -- Virtual network gateway name
    - name -- The name of the resource that is unique within a resource group. This name can be used to access the resource.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az network vnet-gateway nat-rule remove", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the vnet gateway nat rule is met.

    Required Parameters:
    - name -- Name of the VNet gateway.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az network vnet-gateway nat-rule wait", locals())




from ... pyaz_utils import _call_az

def list():
    '''
    Shows the workspace settings in your subscription - these settings let you control which workspace will hold your security data
    '''
    return _call_az("az security workspace-setting list", locals())


def show(name):
    '''
    Shows the workspace settings in your subscription - these settings let you control which workspace will hold your security data

    Required Parameters:
    - name -- name of the resource to be fetched
    '''
    return _call_az("az security workspace-setting show", locals())


def create(name, target_workspace):
    '''
    Creates a workspace settings in your subscription - these settings let you control which workspace will hold your security data

    Required Parameters:
    - name -- name of the resource to be fetched
    - target_workspace -- An ID of the workspace resource that will hold the security data
    '''
    return _call_az("az security workspace-setting create", locals())


def delete(name):
    '''
    Deletes the workspace settings in your subscription - this will make the security events on the subscription be reported to the default workspace

    Required Parameters:
    - name -- name of the resource to be fetched
    '''
    return _call_az("az security workspace-setting delete", locals())




'''
Manage file systems in Azure Data Lake Storage Gen2 account.
'''
from ... pyaz_utils import _call_az
from . import access, directory, file, metadata


def create(name, account_key=None, account_name=None, auth_mode=None, connection_string=None, metadata=None, public_access=None, sas_token=None, timeout=None):
    '''
    Create file system for Azure Data Lake Storage Gen2 account.

    Required Parameters:
    - name -- File system name (i.e. container name).

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - metadata -- Metadata in space-separated key=value pairs. This overwrites any existing metadata.
    - public_access -- Specify whether data in the file system may be accessed publicly and the level of access.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage fs create", locals())


def list(account_key=None, account_name=None, auth_mode=None, connection_string=None, include_metadata=None, prefix=None, sas_token=None):
    '''
    List file systems in ADLS Gen2 account.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - include_metadata -- Specify that file system metadata be returned in the response. The default value is "False".
    - prefix -- Filter the results to return only file systems whose names begin with the specified prefix.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    '''
    return _call_az("az storage fs list", locals())


def show(name, account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None):
    '''
    Show properties of file system in ADLS Gen2 account.

    Required Parameters:
    - name -- File system name (i.e. container name).

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage fs show", locals())


def delete(name, account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None, yes=None):
    '''
    Delete a file system in ADLS Gen2 account.

    Required Parameters:
    - name -- File system name (i.e. container name).

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az storage fs delete", locals())


def exists(name, account_key=None, account_name=None, auth_mode=None, connection_string=None, sas_token=None, timeout=None):
    '''
    Check for the existence of a file system in ADLS Gen2 account.

    Required Parameters:
    - name -- File system name (i.e. container name).

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage fs exists", locals())


def generate_sas(name, account_key=None, account_name=None, as_user=None, auth_mode=None, cache_control=None, connection_string=None, content_disposition=None, content_encoding=None, content_language=None, content_type=None, expiry=None, full_uri=None, https_only=None, ip=None, permissions=None, policy_name=None, start=None):
    '''
    Generate a SAS token for file system in ADLS Gen2 account.

    Required Parameters:
    - name -- File system name (i.e. container name).

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - as_user -- Indicates that this command return the SAS signed with the user delegation key. The expiry parameter and '--auth-mode login' are required if this argument is specified. 
    - auth_mode -- The mode in which to run the command. "login" mode will directly use your login credentials for the authentication. The legacy "key" mode will attempt to query for an account key if no authentication parameters for the account are provided. Environment variable: AZURE_STORAGE_AUTH_MODE
    - cache_control -- Response header value for Cache-Control when resource is accessedusing this shared access signature.
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - content_disposition -- Response header value for Content-Disposition when resource is accessedusing this shared access signature.
    - content_encoding -- Response header value for Content-Encoding when resource is accessedusing this shared access signature.
    - content_language -- Response header value for Content-Language when resource is accessedusing this shared access signature.
    - content_type -- Response header value for Content-Type when resource is accessedusing this shared access signature.
    - expiry -- Specifies the UTC datetime (Y-m-d'T'H:M'Z') at which the SAS becomes invalid. Do not use if a stored access policy is referenced with --id that specifies this value.
    - full_uri -- Indicate that this command return the full blob URI and the shared access signature token.
    - https_only -- Only permit requests made with the HTTPS protocol. If omitted, requests from both the HTTP and HTTPS protocol are permitted.
    - ip -- Specifies the IP address or range of IP addresses from which to accept requests. Supports only IPv4 style addresses.
    - permissions -- The permissions the SAS grants. Allowed values: (d)elete (e)xecute (l)ist (p)ermissions (o)wnership (m)ove (r)ead (w)rite. Do not use if a stored access policy is referenced with --id that specifies this value. Can be combined.
    - policy_name -- The name of a stored access policy.
    - start -- Specifies the UTC datetime (Y-m-d'T'H:M'Z') at which the SAS becomes valid. Do not use if a stored access policy is referenced with --id that specifies this value. Defaults to the time of the request.
    '''
    return _call_az("az storage fs generate-sas", locals())




'''
Configure the Azure Virtual Machine diagnostics extension.
'''
from ... pyaz_utils import _call_az

def set(resource_group, settings, vm_name, no_auto_upgrade_minor_version=None, protected_settings=None, version=None):
    '''
    Configure the Azure VM diagnostics extension.

    Required Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - settings -- json string or a file path, which defines data to be collected.
    - vm_name -- The name of the Virtual Machine. You can configure the default using `az configure --defaults vm=<name>`

    Optional Parameters:
    - no_auto_upgrade_minor_version -- If set, the extension service will not automatically pick or upgrade to the latest minor version, even if the extension is redeployed.
    - protected_settings -- json string or a file path containing private configurations such as storage account keys, etc.
    - version -- version of the diagnostics extension. Will use the latest if not specfied
    '''
    return _call_az("az vm diagnostics set", locals())


def get_default_config(is_windows_os=None):
    '''
    Get the default configuration settings for a VM.

    Optional Parameters:
    - is_windows_os -- for Windows VMs
    '''
    return _call_az("az vm diagnostics get-default-config", locals())




'''
Manage environments for an Azure DevTest Lab.
'''
from ... pyaz_utils import _call_az

def show(lab_name, name, resource_group, expand=None):
    '''
    Get the details for an environment of a lab.

    Required Parameters:
    - lab_name -- The name of the lab.
    - name -- The name of the environment.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - expand -- Specify the $expand query. Example: 'properties($select=deploymentProperties)'
    '''
    return _call_az("az lab environment show", locals())


def list(lab_name, resource_group, expand=None, filter=None, orderby=None, top=None):
    '''
    List environments in a lab.

    Required Parameters:
    - lab_name -- The name of the lab.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - expand -- Specify the $expand query. Example: 'properties($select=deploymentProperties)'
    - filter -- The filter to apply to the operation. Example: '$filter=contains(name,'myName')
    - orderby -- The ordering expression for the results, using OData notation. Example: '$orderby=name desc'
    - top -- The maximum number of resources to return from the operation. Example: '$top=10'
    '''
    return _call_az("az lab environment list", locals())


def delete(lab_name, name, resource_group):
    '''
    Delete an environment from a lab.

    Required Parameters:
    - lab_name -- The name of the lab.
    - name -- The name of the environment.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az lab environment delete", locals())


def create(arm_template, lab_name, name, resource_group, artifact_source_name=None, parameters=None, tags=None):
    '''
    Create an environment in a lab.

    Required Parameters:
    - arm_template -- None
    - lab_name -- None
    - name -- None
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - artifact_source_name -- None
    - parameters -- None
    - tags -- None
    '''
    return _call_az("az lab environment create", locals())




'''
Manage Azure Red Hat OpenShift clusters.
'''
from .. pyaz_utils import _call_az

def create(master_subnet, name, resource_group, worker_subnet, apiserver_visibility=None, client_id=None, client_secret=None, cluster_resource_group=None, domain=None, ingress_visibility=None, location=None, master_vm_size=None, no_wait=None, pod_cidr=None, pull_secret=None, service_cidr=None, tags=None, vnet=None, vnet_resource_group=None, worker_count=None, worker_vm_disk_size_gb=None, worker_vm_size=None):
    '''
    Create a cluster.

    Required Parameters:
    - master_subnet -- Name or ID of master vnet subnet.  If name is supplied, `--vnet` must be supplied.
    - name -- Name of cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - worker_subnet -- Name or ID of worker vnet subnet.  If name is supplied, `--vnet` must be supplied.

    Optional Parameters:
    - apiserver_visibility -- API server visibility.
    - client_id -- Client ID of cluster service principal.
    - client_secret -- Client secret of cluster service principal.
    - cluster_resource_group -- Resource group of cluster.
    - domain -- Domain of cluster.
    - ingress_visibility -- Ingress visibility.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - master_vm_size -- Size of master VMs.
    - no_wait -- Do not wait for the long-running operation to finish.
    - pod_cidr -- CIDR of pod network. Must be a minimum of /18 or larger.
    - pull_secret -- Pull secret of cluster.
    - service_cidr -- CIDR of service network. Must be a minimum of /18 or larger
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - vnet -- Name or ID of vnet.  If name is supplied, `--vnet-resource-group` must be supplied.
    - vnet_resource_group -- Name of vnet resource group.
    - worker_count -- Count of worker VMs.
    - worker_vm_disk_size_gb -- Disk size in GB of worker VMs.
    - worker_vm_size -- Size of worker VMs.
    '''
    return _call_az("az aro create", locals())


def delete(name, resource_group, no_wait=None, yes=None):
    '''
    Delete a cluster.

    Required Parameters:
    - name -- Name of cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az aro delete", locals())


def list(resource_group=None):
    '''
    List clusters.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az aro list", locals())


def show(name, resource_group):
    '''
    Get the details of a cluster.

    Required Parameters:
    - name -- Name of cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az aro show", locals())


def update(name, resource_group, client_id=None, client_secret=None, no_wait=None, refresh_credentials=None):
    '''
    Update a cluster.

    Required Parameters:
    - name -- Name of cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - client_id -- Client ID of cluster service principal.
    - client_secret -- Client secret of cluster service principal.
    - no_wait -- Do not wait for the long-running operation to finish.
    - refresh_credentials -- Refresh cluster application credentials.
    '''
    return _call_az("az aro update", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, interval=None, timeout=None, updated=None):
    '''
    Wait for a cluster to reach a desired state.

    Required Parameters:
    - name -- Name of cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az aro wait", locals())


def list_credentials(name, resource_group):
    '''
    List credentials of a cluster.

    Required Parameters:
    - name -- Name of cluster.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az aro list-credentials", locals())




'''
Manage and update CLI extensions.
'''
from .. pyaz_utils import _call_az

def add(index=None, name=None, pip_extra_index_urls=None, pip_proxy=None, source=None, system=None, upgrade=None, version=None, yes=None):
    '''
    Add an extension.

    Optional Parameters:
    - index -- ==SUPPRESS==
    - name -- Name of extension
    - pip_extra_index_urls -- Space-separated list of extra URLs of package indexes to use. This should point to a repository compliant with PEP 503 (the simple repository API) or a local directory laid out in the same format.
    - pip_proxy -- Proxy for pip to use for extension dependencies in the form of [user:passwd@]proxy.server:port
    - source -- Filepath or URL to an extension
    - system -- None
    - upgrade -- Update the extension if already installed, otherwise just install the extension.
    - version -- The specific version of an extension
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az extension add", locals())


def remove(name):
    '''
    Remove an extension.

    Required Parameters:
    - name -- Name of extension
    '''
    return _call_az("az extension remove", locals())


def list():
    '''
    List the installed extensions.
    '''
    return _call_az("az extension list", locals())


def show(name):
    '''
    Show an extension.

    Required Parameters:
    - name -- Name of extension
    '''
    return _call_az("az extension show", locals())


def list_available(index=None, show_details=None):
    '''
    List publicly available extensions.

    Optional Parameters:
    - index -- ==SUPPRESS==
    - show_details -- Show the raw data from the extension index.
    '''
    return _call_az("az extension list-available", locals())


def update(name, index=None, pip_extra_index_urls=None, pip_proxy=None):
    '''
    Update an extension.

    Required Parameters:
    - name -- Name of extension

    Optional Parameters:
    - index -- ==SUPPRESS==
    - pip_extra_index_urls -- Space-separated list of extra URLs of package indexes to use. This should point to a repository compliant with PEP 503 (the simple repository API) or a local directory laid out in the same format.
    - pip_proxy -- Proxy for pip to use for extension dependencies in the form of [user:passwd@]proxy.server:port
    '''
    return _call_az("az extension update", locals())


def list_versions(name, index=None):
    '''
    List available versions for an extension.

    Required Parameters:
    - name -- Name of extension

    Optional Parameters:
    - index -- ==SUPPRESS==
    '''
    return _call_az("az extension list-versions", locals())




'''
Manage table storage entities.
'''
from ... pyaz_utils import _call_az

def query(table_name, accept=None, account_key=None, account_name=None, connection_string=None, filter=None, marker=None, num_results=None, sas_token=None, select=None, timeout=None):
    '''
    List entities which satisfy a query.

    Required Parameters:
    - table_name --  The name of the table to query.

    Optional Parameters:
    - accept -- Specifies how much metadata to include in the response payload.
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - filter --  Returns only entities that satisfy the specified filter. Note that no more than 15 discrete comparisons are permitted within a $filter string. See http://msdn.microsoft.com/en-us/library/windowsazure/dd894031.aspx for more information on constructing filters.
    - marker --  An opaque continuation object. This value can be retrieved from the next_marker field of a previous generator object if max_results was specified and that generator has finished enumerating results. If specified, this generator will begin returning results from the point where the previous generator stopped.
    - num_results --  The maximum number of entities to return.
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - select -- Space-separated list of properties to return for each entity.
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage entity query", locals())


def replace(entity, table_name, account_key=None, account_name=None, connection_string=None, if_match=None, sas_token=None, timeout=None):
    '''
    

    Required Parameters:
    - entity --  The entity to update. Could be a dict or an entity object. Must contain a PartitionKey and a RowKey.
    - table_name --  The name of the table containing the entity to update.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - if_match --  The client may specify the ETag for the entity on the request in order to compare to the ETag maintained by the service for the purpose of optimistic concurrency. The update operation will be performed only if the ETag sent by the client matches the value maintained by the server, indicating that the entity has not been modified since it was retrieved by the client. To force an unconditional update, set If-Match to the wildcard character (*).
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage entity replace", locals())


def merge(entity, table_name, account_key=None, account_name=None, connection_string=None, if_match=None, sas_token=None, timeout=None):
    '''
    

    Required Parameters:
    - entity --  The entity to merge. Could be a dict or an entity object. Must contain a PartitionKey and a RowKey.
    - table_name --  The name of the table containing the entity to merge.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - if_match --  The client may specify the ETag for the entity on the request in order to compare to the ETag maintained by the service for the purpose of optimistic concurrency. The merge operation will be performed only if the ETag sent by the client matches the value maintained by the server, indicating that the entity has not been modified since it was retrieved by the client. To force an unconditional merge, set If-Match to the wildcard character (*).
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage entity merge", locals())


def delete(partition_key, row_key, table_name, account_key=None, account_name=None, connection_string=None, if_match=None, sas_token=None, timeout=None):
    '''
    

    Required Parameters:
    - partition_key --  The PartitionKey of the entity.
    - row_key --  The RowKey of the entity.
    - table_name --  The name of the table containing the entity to delete.

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - if_match --  The client may specify the ETag for the entity on the request in order to compare to the ETag maintained by the service for the purpose of optimistic concurrency. The delete operation will be performed only if the ETag sent by the client matches the value maintained by the server, indicating that the entity has not been modified since it was retrieved by the client. To force an unconditional delete, set If-Match to the wildcard character (*).
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage entity delete", locals())


def show(partition_key, row_key, table_name, accept=None, account_key=None, account_name=None, connection_string=None, sas_token=None, select=None, timeout=None):
    '''
    

    Required Parameters:
    - partition_key --  The PartitionKey of the entity.
    - row_key --  The RowKey of the entity.
    - table_name --  The name of the table to get the entity from.

    Optional Parameters:
    - accept --  Specifies the accepted content type of the response payload. See :class:`~azure.storage.table.models.TablePayloadFormat` for possible values.
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - select -- Space-separated list of properties to return for each entity.
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage entity show", locals())


def insert(entity, table_name, account_key=None, account_name=None, connection_string=None, if_exists=None, sas_token=None, timeout=None):
    '''
    Insert an entity into a table.

    Required Parameters:
    - entity -- None
    - table_name -- None

    Optional Parameters:
    - account_key -- Storage account key. Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_KEY
    - account_name -- Storage account name. Related environment variable: AZURE_STORAGE_ACCOUNT. Must be used in conjunction with either storage account key or a SAS token. If neither are present, the command will try to query the storage account key using the authenticated Azure account. If a large number of storage commands are executed the API quota may be hit
    - connection_string -- Storage account connection string. Environment variable: AZURE_STORAGE_CONNECTION_STRING
    - if_exists -- None
    - sas_token -- A Shared Access Signature (SAS). Must be used in conjunction with storage account name. Environment variable: AZURE_STORAGE_SAS_TOKEN
    - timeout -- Request timeout in seconds. Applies to each call to the service.
    '''
    return _call_az("az storage entity insert", locals())




'''
Manage network interfaces.
'''
from ... pyaz_utils import _call_az
from . import ip_config


def create(name, resource_group, subnet, accelerated_networking=None, app_gateway_address_pools=None, application_security_groups=None, dns_servers=None, edge_zone=None, gateway_name=None, internal_dns_name=None, ip_forwarding=None, lb_address_pools=None, lb_inbound_nat_rules=None, lb_name=None, location=None, network_security_group=None, no_wait=None, private_ip_address=None, private_ip_address_version=None, public_ip_address=None, tags=None, vnet_name=None):
    '''
    Create a network interface.

    Required Parameters:
    - name -- The network interface (NIC).
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - subnet -- Name or ID of an existing subnet. If name specified, also specify --vnet-name. If you want to use an existing subnet in other resource group, please provide the ID instead of the name of the subnet

    Optional Parameters:
    - accelerated_networking -- Enable accelerated networking.
    - app_gateway_address_pools -- Space-separated list of names or IDs of application gateway backend address pools to associate with the NIC. If names are used, --gateway-name must be specified.
    - application_security_groups -- Space-separated list of application security groups.
    - dns_servers -- Space-separated list of DNS server IP addresses.
    - edge_zone -- The name of edge zone.
    - gateway_name -- The name of the application gateway to use when adding address pools by name (ignored when IDs are specified).
    - internal_dns_name -- The internal DNS name label.
    - ip_forwarding -- Enable IP forwarding.
    - lb_address_pools -- Space-separated list of names or IDs of load balancer address pools to associate with the NIC. If names are used, --lb-name must be specified.
    - lb_inbound_nat_rules -- Space-separated list of names or IDs of load balancer inbound NAT rules to associate with the NIC. If names are used, --lb-name must be specified.
    - lb_name -- The name of the load balancer to use when adding NAT rules or address pools by name (ignored when IDs are specified).
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - network_security_group -- Name or ID of an existing network security group, or none by default.
    - no_wait -- Do not wait for the long-running operation to finish.
    - private_ip_address -- Static private IP address to use.
    - private_ip_address_version -- The private IP address version to use.
    - public_ip_address -- Name or ID of an existing public IP address, or none by default.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - vnet_name -- The virtual network (VNet) name.
    '''
    return _call_az("az network nic create", locals())


def delete(name, resource_group, no_wait=None):
    '''
    Delete a network interface.

    Required Parameters:
    - name -- The network interface (NIC).
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    '''
    return _call_az("az network nic delete", locals())


def show(name, resource_group, expand=None):
    '''
    Get the details of a network interface.

    Required Parameters:
    - name -- The network interface (NIC).
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - expand -- Expands referenced resources.
    '''
    return _call_az("az network nic show", locals())


def list(resource_group=None):
    '''
    List network interfaces.

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network nic list", locals())


def show_effective_route_table(name, resource_group):
    '''
    Show the effective route table applied to a network interface.

    Required Parameters:
    - name -- The network interface (NIC).
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network nic show-effective-route-table", locals())


def list_effective_nsg(name, resource_group):
    '''
    List all effective network security groups applied to a network interface.

    Required Parameters:
    - name -- The network interface (NIC).
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az network nic list-effective-nsg", locals())


def update(name, resource_group, accelerated_networking=None, add=None, dns_servers=None, force_string=None, internal_dns_name=None, ip_forwarding=None, network_security_group=None, no_wait=None, remove=None, set=None):
    '''
    Update a network interface.

    Required Parameters:
    - name -- The network interface (NIC).
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - accelerated_networking -- Enable accelerated networking.
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - dns_servers -- Space-separated list of DNS server IP addresses. Use ""('""' in PowerShell) to revert to default Azure servers.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - internal_dns_name -- The internal DNS name label.
    - ip_forwarding -- Enable IP forwarding.
    - network_security_group -- Name or ID of the associated network security group.
    - no_wait -- Do not wait for the long-running operation to finish.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    '''
    return _call_az("az network nic update", locals())


def wait(name, resource_group, created=None, custom=None, deleted=None, exists=None, expand=None, interval=None, timeout=None, updated=None):
    '''
    Place the CLI in a waiting state until a condition of the network interface is met.

    Required Parameters:
    - name -- The network interface (NIC).
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - created -- wait until created with 'provisioningState' at 'Succeeded'
    - custom -- Wait until the condition satisfies a custom JMESPath query. E.g. provisioningState!='InProgress', instanceView.statuses[?code=='PowerState/running']
    - deleted -- wait until deleted
    - exists -- wait until the resource exists
    - expand -- Expands referenced resources.
    - interval -- polling interval in seconds
    - timeout -- maximum wait in seconds
    - updated -- wait until updated with provisioningState at 'Succeeded'
    '''
    return _call_az("az network nic wait", locals())




'''
Manage credentials of a token for an Azure Container Registry.
'''
from .... pyaz_utils import _call_az

def delete(name, registry, password1=None, password2=None, resource_group=None):
    '''
    Delete a token credential.

    Required Parameters:
    - name -- The name of the token.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - password1 -- Flag indicating if first password should be deleted
    - password2 -- Flag indicating if second password should be deleted.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr token credential delete", locals())


def generate(name, registry, expiration=None, expiration_in_days=None, password1=None, password2=None, resource_group=None):
    '''
    Generate or replace one or both passwords of a token for an Azure Container Registry. For using token and password to access a container registry, see https://aka.ms/acr/repo-permissions.

    Required Parameters:
    - name -- The name of the token.
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - expiration -- UTC time for which the credentials will be valid. In the format of %Y-%m-%dT%H:%M:%SZ, e.g. 2025-12-31T12:59:59Z
    - expiration_in_days -- Number of days for which the credentials will be valid. If not specified, the expiration will default to the max value "9999-12-31T23:59:59.999999+00:00"
    - password1 -- Flag indicating if password1 should be generated.
    - password2 -- Flag indicating if password2 should be generated.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr token credential generate", locals())




from .... pyaz_utils import _call_az

def set(cluster_name, resource_group, upgrade_mode, version=None):
    '''
    Change the  upgrade type for a cluster.

    Required Parameters:
    - cluster_name -- Specify the name of the cluster, if not given it will be same as resource group name
    - resource_group -- Specify the resource group name. You can configure the default group using `az configure --defaults group=<name>`
    - upgrade_mode -- cluster upgrade mode

    Optional Parameters:
    - version -- cluster code version
    '''
    return _call_az("az sf cluster upgrade-type set", locals())




'''
Commands to list and stream files in job's output directories.
'''
from .... pyaz_utils import _call_az

def list(experiment, job, resource_group, workspace, expiry=None, output_directory_id=None, path=None):
    '''
    List job's output files in a directory with given id.

    Required Parameters:
    - experiment -- Name of experiment.
    - job -- Name of job.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace -- Name of workspace.

    Optional Parameters:
    - expiry -- Time in minutes for how long generated download URL should remain valid.
    - output_directory_id -- The Id of the job's output directory (as specified by "id" element in outputDirectories collection in the job create parameters).
    - path -- Relative path in the given output directory.
    '''
    return _call_az("az batchai job file list", locals())


def stream(experiment, file_name, job, resource_group, workspace, output_directory_id=None, path=None):
    '''
    Stream the content of a file (similar to 'tail -f').

    Required Parameters:
    - experiment -- Name of experiment.
    - file_name -- The name of the file to stream.
    - job -- Name of job.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - workspace -- Name of workspace.

    Optional Parameters:
    - output_directory_id -- The Id of the job's output directory (as specified by "id" element in outputDirectories collection in the job create parameters).
    - path -- Relative path in the given output directory.
    '''
    return _call_az("az batchai job file stream", locals())




from .... pyaz_utils import _call_az

def download(destination, node_id, pool_id, account_endpoint=None, account_key=None, account_name=None):
    '''
    

    Required Parameters:
    - destination -- The path to the destination file or directory.
    - node_id -- The ID of the Compute Node for which you want to get the Remote Desktop Protocol file.
    - pool_id -- The ID of the Pool that contains the Compute Node.

    Optional Parameters:
    - account_endpoint -- Batch service endpoint. Alternatively, set by environment variable: AZURE_BATCH_ENDPOINT
    - account_key -- Batch account key. Alternatively, set by environment variable: AZURE_BATCH_ACCESS_KEY
    - account_name -- Batch account name. Alternatively, set by environment variable: AZURE_BATCH_ACCOUNT
    '''
    return _call_az("az batch node remote-desktop download", locals())




'''
Manage Azure API Management API Operations.
'''
from .... pyaz_utils import _call_az

def list(api_id, resource_group, service_name):
    '''
    List a collection of the operations for the specified API.

    Required Parameters:
    - api_id -- API identifier. Must be unique in the current API Management service instance. Non-current revision has ;rev=n as a suffix where n is the revision number.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the API Management service instance.
    '''
    return _call_az("az apim api operation list", locals())


def show(api_id, operation_id, resource_group, service_name):
    '''
    Gets the details of the API Operation specified by its identifier.

    Required Parameters:
    - api_id -- API identifier. Must be unique in the current API Management service instance. Non-current revision has ;rev=n as a suffix where n is the revision number.
    - operation_id -- Operation identifier within an API. Must be unique in the current API Management service instance.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the API Management service instance.
    '''
    return _call_az("az apim api operation show", locals())


def create(api_id, display_name, method, resource_group, service_name, url_template, description=None, if_match=None, operation_id=None, template_parameters=None):
    '''
    Creates a new operation in the API

    Required Parameters:
    - api_id -- API identifier. Must be unique in the current API Management service instance. Non-current revision has ;rev=n as a suffix where n is the revision number.
    - display_name -- Required. Operation Name.
    - method -- Required. A Valid HTTP Operation Method. Typical Http Methods like GET, PUT, POST but not limited by only them.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the API Management service instance.
    - url_template -- Relative URL template identifying the target resource for this operation. May include parameters.

    Optional Parameters:
    - description -- Description of the operation. May include HTML formatting tags.
    - if_match -- ETag of the Entity.
    - operation_id -- Operation identifier within an API. Must be unique in the current API Management service instance.
    - template_parameters -- Collection of URL template parameters.
    '''
    return _call_az("az apim api operation create", locals())


def update(api_id, operation_id, resource_group, service_name, add=None, description=None, display_name=None, force_string=None, if_match=None, method=None, remove=None, set=None, url_template=None):
    '''
    Updates the details of the operation in the API specified by its identifier.

    Required Parameters:
    - api_id -- API identifier. Must be unique in the current API Management service instance. Non-current revision has ;rev=n as a suffix where n is the revision number.
    - operation_id -- Operation identifier within an API. Must be unique in the current API Management service instance.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the API Management service instance.

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - description -- Description of the operation. May include HTML formatting tags.
    - display_name -- Required. Operation Name.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - if_match -- ETag of the Entity.
    - method -- Required. A Valid HTTP Operation Method. Typical Http Methods like GET, PUT, POST but not limited by only them.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - url_template -- Relative URL template identifying the target resource for this operation. May include parameters.
    '''
    return _call_az("az apim api operation update", locals())


def delete(api_id, operation_id, resource_group, service_name, if_match=None):
    '''
    Deletes the specified operation in the API.

    Required Parameters:
    - api_id -- API identifier. Must be unique in the current API Management service instance. Non-current revision has ;rev=n as a suffix where n is the revision number.
    - operation_id -- Operation identifier within an API. Must be unique in the current API Management service instance.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - service_name -- The name of the API Management service instance.

    Optional Parameters:
    - if_match -- ETag of the Entity.
    '''
    return _call_az("az apim api operation delete", locals())




from .... pyaz_utils import _call_az

def show(registry, resource_group=None):
    '''
    Show the configured content-trust policy for an Azure Container Registry.

    Required Parameters:
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az acr config content-trust show", locals())


def update(registry, resource_group=None, status=None):
    '''
    Update content-trust policy for an Azure Container Registry.

    Required Parameters:
    - registry -- The name of the container registry. You can configure the default registry name using `az configure --defaults acr=<registry name>`

    Optional Parameters:
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - status -- Indicates whether content-trust is enabled.
    '''
    return _call_az("az acr config content-trust update", locals())




from ... pyaz_utils import _call_az

def approve(description=None, id=None, name=None, resource_group=None, resource_name=None, type=None):
    '''
    Approve a private endpoint connection.

    Optional Parameters:
    - description -- Comments for the approval.
    - id -- ID of the private endpoint connection
    - name -- Name of the private endpoint connection
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_name -- Name of the resource
    - type -- Type of the resource.
    '''
    return _call_az("az network private-endpoint-connection approve", locals())


def reject(description=None, id=None, name=None, resource_group=None, resource_name=None, type=None):
    '''
    Reject a private endpoint connection.

    Optional Parameters:
    - description -- Comments for the rejection.
    - id -- ID of the private endpoint connection
    - name -- Name of the private endpoint connection
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_name -- Name of the resource
    - type -- Type of the resource.
    '''
    return _call_az("az network private-endpoint-connection reject", locals())


def delete(id=None, name=None, resource_group=None, resource_name=None, type=None, yes=None):
    '''
    Delete a private endpoint connection.

    Optional Parameters:
    - id -- ID of the private endpoint connection
    - name -- Name of the private endpoint connection
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_name -- Name of the resource
    - type -- Type of the resource.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az network private-endpoint-connection delete", locals())


def show(id=None, name=None, resource_group=None, resource_name=None, type=None):
    '''
    Show a private endpoint connection.

    Optional Parameters:
    - id -- ID of the private endpoint connection
    - name -- Name of the private endpoint connection
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - resource_name -- Name of the resource
    - type -- Type of the resource.
    '''
    return _call_az("az network private-endpoint-connection show", locals())


def list(id=None, name=None, resource_group=None, type=None):
    '''
    List all private endpoint connections.

    Optional Parameters:
    - id -- ID of the resource
    - name -- Name of the resource. If provided, --type and --resource-group must be provided too
    - resource_group -- Name of resource group. If provided, --name and --type must be provided too
    - type -- Type of the resource. If provided, --name and --resource-group must be provided too
    '''
    return _call_az("az network private-endpoint-connection list", locals())




from ... pyaz_utils import _call_az

def list():
    '''
    Lists available operations for the Kusto sub-resources inside Microsoft.Synapse provider.
    '''
    return _call_az("az synapse kusto-operation list", locals())




'''
Manage SQL managed instances.
'''
from ... pyaz_utils import _call_az
from . import ad_admin, ad_only_auth, key, op, tde_key


def create(name, resource_group, subnet, admin_password=None, admin_user=None, assign_identity=None, backup_storage_redundancy=None, capacity=None, collation=None, enable_ad_only_auth=None, external_admin_name=None, external_admin_principal_type=None, external_admin_sid=None, family=None, identity_type=None, key_id=None, license_type=None, location=None, maint_config_id=None, minimal_tls_version=None, no_wait=None, primary_user_assigned_identity_id=None, proxy_override=None, public_data_endpoint_enabled=None, storage=None, tags=None, tier=None, timezone_id=None, user_assigned_identity_id=None, vnet_name=None, yes=None):
    '''
    Create a managed instance.

    Required Parameters:
    - name -- The managed instance name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - subnet -- Name or ID of the subnet that allows access to an Azure Sql Managed Instance. If subnet name is provided, --vnet-name must be provided.

    Optional Parameters:
    - admin_password -- The administrator login password (required for managed instance creation).
    - admin_user -- Administrator username for the managed instance. Can only be specified when the managed instance is being created (and is required for creation).
    - assign_identity -- Generate and assign an Azure Active Directory Identity for this managed instance for use with key management services like Azure KeyVault.
    - backup_storage_redundancy -- Backup storage redundancy used to store backups. Allowed values include: Local, Zone, Geo.
    - capacity -- The capacity of the managed instance in integer number of vcores.
    - collation -- The collation of the managed instance.
    - enable_ad_only_auth -- Enable Azure Active Directory Only Authentication for this server.
    - external_admin_name -- Display name of the Azure AD administrator user, group or application.
    - external_admin_principal_type -- User, Group or Application
    - external_admin_sid -- The unique ID of the Azure AD administrator. Object Id for User or Group, Client Id for Applications
    - family -- The compute generation component of the sku. Allowed values include: Gen4, Gen5.
    - identity_type -- Type of Identity to be used. Possible values are SystemAsssigned,UserAssigned, SystemAssignedUserAssigned and None.
    - key_id -- The key vault URI for encryption.
    - license_type -- The license type to apply for this managed instance.
    - location -- Location. Values from: `az account list-locations`. You can configure the default location using `az configure --defaults location=<location>`.
    - maint_config_id -- Assign maintenance configuration to this managed instance.
    - minimal_tls_version -- The minimal TLS version enforced by the managed instance for inbound connections.
    - no_wait -- Do not wait for the long-running operation to finish.
    - primary_user_assigned_identity_id -- The ID of the primary user managed identity.
    - proxy_override -- The connection type used for connecting to the instance.
    - public_data_endpoint_enabled -- Whether or not the public data endpoint is enabled for the instance.
    - storage -- The storage size of the managed instance. Storage size must be specified in increments of 32 GB
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - tier -- The edition component of the sku. Allowed values include: GeneralPurpose, BusinessCritical.
    - timezone_id -- The time zone id for the instance to set. A list of time zone ids is exposed through the sys.time_zone_info (Transact-SQL) view.
    - user_assigned_identity_id -- Generate and assign an User Managed Identity(UMI) for this server.
    - vnet_name -- The virtual network name
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az sql mi create", locals())


def delete(name, resource_group, no_wait=None, yes=None):
    '''
    Delete a managed instance.

    Required Parameters:
    - name -- The managed instance name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - yes -- Do not prompt for confirmation.
    '''
    return _call_az("az sql mi delete", locals())


def show(name, resource_group, expand_ad_admin=None):
    '''
    Get the details for a managed instance.

    Required Parameters:
    - name -- The managed instance name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - expand_ad_admin -- Expand the Active Directory Administrator for the server.
    '''
    return _call_az("az sql mi show", locals())


def list(expand_ad_admin=None, resource_group=None):
    '''
    List available managed instances.

    Optional Parameters:
    - expand_ad_admin -- Expand the Active Directory Administrator for the server.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    '''
    return _call_az("az sql mi list", locals())


def update(name, resource_group, add=None, admin_password=None, assign_identity=None, capacity=None, family=None, force_string=None, identity_type=None, key_id=None, license_type=None, maint_config_id=None, minimal_tls_version=None, no_wait=None, primary_user_assigned_identity_id=None, proxy_override=None, public_data_endpoint_enabled=None, remove=None, set=None, storage=None, subnet=None, tags=None, tier=None, user_assigned_identity_id=None, vnet_name=None):
    '''
    Update a managed instance.

    Required Parameters:
    - name -- The managed instance name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - add -- Add an object to a list of objects by specifying a path and key value pairs.  Example: --add property.listProperty <key=value, string or JSON string>
    - admin_password -- The administrator login password (required for managed instance creation).
    - assign_identity -- Generate and assign an Azure Active Directory Identity for this managed instance for use with key management services like Azure KeyVault. If identity is already assigned - do nothing.
    - capacity -- The capacity of the managed instance in integer number of vcores.
    - family -- The compute generation component of the sku. Allowed values include: Gen4, Gen5.
    - force_string -- When using 'set' or 'add', preserve string literals instead of attempting to convert to JSON.
    - identity_type -- Type of Identity to be used. Possible values are SystemAsssigned,UserAssigned, SystemAssignedUserAssigned and None.
    - key_id -- The key vault URI for encryption.
    - license_type -- The license type to apply for this managed instance.
    - maint_config_id -- Change maintenance configuration for this managed instance.
    - minimal_tls_version -- The minimal TLS version enforced by the managed instance for inbound connections.
    - no_wait -- Do not wait for the long-running operation to finish.
    - primary_user_assigned_identity_id -- The ID of the primary user managed identity.
    - proxy_override -- The connection type used for connecting to the instance.
    - public_data_endpoint_enabled -- Whether or not the public data endpoint is enabled for the instance.
    - remove -- Remove a property or an element from a list.  Example: --remove property.list <indexToRemove> OR --remove propertyToRemove
    - set -- Update an object by specifying a property path and value to set.  Example: --set property1.property2=<value>
    - storage -- The storage size of the managed instance. Storage size must be specified in increments of 32 GB
    - subnet -- Name or ID of the subnet that allows access to an Azure Sql Managed Instance. If subnet name is provided, --vnet-name must be provided.
    - tags -- space-separated tags: key[=value] [key[=value] ...]. Use '' to clear existing tags.
    - tier -- The edition component of the sku. Allowed values include: GeneralPurpose, BusinessCritical.
    - user_assigned_identity_id -- Generate and assign an User Managed Identity(UMI) for this server.
    - vnet_name -- The virtual network name
    '''
    return _call_az("az sql mi update", locals())


def failover(name, resource_group, no_wait=None, replica_type=None):
    '''
    Failover a managed instance.

    Required Parameters:
    - name -- The managed instance name
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`

    Optional Parameters:
    - no_wait -- Do not wait for the long-running operation to finish.
    - replica_type -- The type of replica to be failed over.
    '''
    return _call_az("az sql mi failover", locals())




'''
Manage sensitivity classification recommendations.
'''
from ..... pyaz_utils import _call_az

def list(name, resource_group, server, filter=None, include_disabled_recommendations=None):
    '''
    List the recommended sensitivity classifications of a given database.

    Required Parameters:
    - name -- Name of the Azure SQL Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`

    Optional Parameters:
    - filter -- An OData filter expression that filters elements in the collection.
    - include_disabled_recommendations -- Specifies whether to include disabled recommendations or not.
    '''
    return _call_az("az sql db classification recommendation list", locals())


def enable(column, name, resource_group, schema, server, table):
    '''
    Enable sensitivity recommendations for a given column (recommendations are enabled by default on all columns).

    Required Parameters:
    - column -- The name of the column.
    - name -- Name of the Azure SQL Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - schema -- The name of the schema.
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    - table -- The name of the table.
    '''
    return _call_az("az sql db classification recommendation enable", locals())


def disable(column, name, resource_group, schema, server, table):
    '''
    Disable sensitivity recommendations for a given column (recommendations are enabled by default on all columns).

    Required Parameters:
    - column -- The name of the column.
    - name -- Name of the Azure SQL Database.
    - resource_group -- Name of resource group. You can configure the default group using `az configure --defaults group=<name>`
    - schema -- The name of the schema.
    - server -- Name of the Azure SQL server. You can configure the default using `az configure --defaults sql-server=<name>`
    - table -- The name of the table.
    '''
    return _call_az("az sql db classification recommendation disable", locals())

